@@ -18,11 +18,28 @@ path.append(os.path.join(anyscale_dir, "client"))
 path.append(os.path.join(anyscale_dir, "sdk"))
 
 import anyscale
-from anyscale import compute_config, image, integrations, job, llm, schedule, service
+from anyscale import (
+    aggregated_instance_usage,
+    cloud,
+    compute_config,
+    image,
+    integrations,
+    job,
+    llm,
+    organization_invitation,
+    project,
+    resource_quota,
+    schedule,
+    service,
+    service_account,
+    user,
+)
 from anyscale._private.anyscale_client import AnyscaleClient, AnyscaleClientInterface
 from anyscale._private.sdk.base_sdk import Timer
+from anyscale.aggregated_instance_usage import AggregatedInstanceUsageSDK
 from anyscale.authenticate import AuthenticationBlock
 from anyscale.cli_logger import BlockLogger
+from anyscale.cloud import CloudSDK
 from anyscale.cluster import get_job_submission_client_cluster_info
 from anyscale.cluster_compute import get_cluster_compute_from_name
 from anyscale.compute_config import ComputeConfigSDK
@@ -30,9 +47,14 @@ from anyscale.connect import ClientBuilder
 from anyscale.image import ImageSDK
 from anyscale.job import JobSDK
 from anyscale.llm import LLMSDK
+from anyscale.organization_invitation import OrganizationInvitationSDK
+from anyscale.project import ProjectSDK
+from anyscale.resource_quota import ResourceQuotaSDK
 from anyscale.schedule import ScheduleSDK
 from anyscale.sdk.anyscale_client.sdk import AnyscaleSDK
 from anyscale.service import ServiceSDK
+from anyscale.service_account import ServiceAccountSDK
+from anyscale.user import UserSDK
 from anyscale.workspace import WorkspaceSDK
 
 
@@ -46,6 +68,10 @@ for attr, _ in inspect.getmembers(ClientBuilder, inspect.isfunction):
     if attr.startswith("_"):
         continue
 
+    # This is exposed in anyscale/cloud/__init__.py since anyscale.cloud is used as the SDK module too.
+    if attr == "cloud":
+        continue
+
     def _new_builder(attr: str) -> Any:
         target = getattr(ClientBuilder, attr)
 
@@ -89,12 +115,23 @@ class Anyscale:
             api_clients=(auth_block.anyscale_api_client, auth_block.api_client),
             host=_host,
         )
+        self._aggregated_instance_usage_sdk = AggregatedInstanceUsageSDK(
+            client=self._anyscale_client
+        )
         self._job_sdk = JobSDK(client=self._anyscale_client)
         self._service_sdk = ServiceSDK(client=self._anyscale_client)
         self._compute_config_sdk = ComputeConfigSDK(client=self._anyscale_client)
+        self._cloud_sdk = CloudSDK(client=self._anyscale_client)
         self._schedule_sdk = ScheduleSDK(client=self._anyscale_client)
         self._image_sdk = ImageSDK(client=self._anyscale_client)
         self._llm_sdk = LLMSDK(client=self._anyscale_client)
+        self._organization_invitation_sdk = OrganizationInvitationSDK(
+            client=self._anyscale_client
+        )
+        self._project_sdk = ProjectSDK(client=self._anyscale_client)
+        self._resource_quota_sdk = ResourceQuotaSDK(client=self._anyscale_client)
+        self._service_account_sdk = ServiceAccountSDK(client=self._anyscale_client)
+        self._user_sdk = UserSDK(client=self._anyscale_client)
         self._workspace_sdk = WorkspaceSDK(client=self._anyscale_client)
 
     @classmethod
@@ -105,6 +142,9 @@ class Anyscale:
         obj = cls.__new__(cls)
         super(Anyscale, obj).__init__()
         obj._anyscale_client = client  # noqa: SLF001
+        obj._aggregated_instance_usage_sdk = AggregatedInstanceUsageSDK(  # noqa: SLF001
+            client=client, logger=logger, timer=timer
+        )
         obj._job_sdk = JobSDK(client=client, logger=logger, timer=timer)  # noqa: SLF001
         obj._service_sdk = ServiceSDK(  # noqa: SLF001
             client=client, logger=logger, timer=timer
@@ -112,15 +152,37 @@ class Anyscale:
         obj._compute_config_sdk = ComputeConfigSDK(  # noqa: SLF001
             client=client, logger=logger, timer=timer
         )
+        obj._cloud_sdk = CloudSDK(  # noqa: SLF001
+            client=client, logger=logger, timer=timer
+        )
         obj._schedule_sdk = ScheduleSDK(  # noqa: SLF001
             client=client, logger=logger, timer=timer,
         )
         obj._image_sdk = ImageSDK(client=client, logger=logger)  # noqa: SLF001
+        obj._organization_invitation_sdk = OrganizationInvitationSDK(  # noqa: SLF001
+            client=client, logger=logger
+        )
+        obj._project_sdk = ProjectSDK(  # noqa: SLF001
+            client=client, logger=logger, timer=timer
+        )
+        obj._service_account_sdk = ServiceAccountSDK(  # noqa: SLF001
+            client=client, logger=logger, timer=timer
+        )
+        obj._user_sdk = UserSDK(  # noqa: SLF001
+            client=client, logger=logger, timer=timer
+        )
+        obj._resource_quota_sdk = ResourceQuotaSDK(  # noqa: SLF001
+            client=client, logger=logger, timer=timer
+        )
         obj._workspace_sdk = WorkspaceSDK(  # noqa: SLF001
             client=client, logger=logger, timer=timer,
         )
         return obj
 
+    @property
+    def aggregated_instance_usage(self) -> AggregatedInstanceUsageSDK:  # noqa: F811
+        return self._aggregated_instance_usage_sdk
+
     @property
     def job(self) -> JobSDK:  # noqa: F811
         return self._job_sdk
@@ -133,6 +195,10 @@ class Anyscale:
     def compute_config(self) -> ComputeConfigSDK:  # noqa: F811
         return self._compute_config_sdk
 
+    @property
+    def cloud(self) -> CloudSDK:  # noqa: F811
+        return self._cloud_sdk
+
     @property
     def schedule(self) -> ScheduleSDK:  # noqa: F811
         return self._schedule_sdk
@@ -145,6 +211,26 @@ class Anyscale:
     def llm(self) -> LLMSDK:  # noqa: F811
         return self._llm_sdk
 
+    @property
+    def organization_invitation(self) -> OrganizationInvitationSDK:  # noqa: F811
+        return self._organization_invitation_sdk
+
+    @property
+    def project(self) -> ProjectSDK:  # noqa: F811
+        return self._project_sdk
+
+    @property
+    def resource_quota(self) -> ResourceQuotaSDK:  # noqa: F811
+        return self._resource_quota_sdk
+
+    @property
+    def service_account(self) -> ServiceAccountSDK:  # noqa: F811
+        return self._service_account_sdk
+
+    @property
+    def user(self) -> UserSDK:  # noqa: F811
+        return self._user_sdk
+
     @property
     def workspace(self) -> WorkspaceSDK:  # noqa: F811
         return self._workspace_sdk
