@@ -6,6 +6,7 @@ import json
 import logging
 import os
 import pathlib
+import re
 import time
 from typing import Any, Callable, Dict, Generator, IO, List, Optional, Tuple
 from urllib.parse import urlparse
@@ -33,6 +34,10 @@ from anyscale.authenticate import AuthenticationBlock, get_auth_api_client
 from anyscale.cli_logger import BlockLogger
 from anyscale.client.openapi_client.api.default_api import DefaultApi as InternalApi
 from anyscale.client.openapi_client.models import (
+    AdminCreatedUser,
+    AdminCreateUser,
+    AnyscaleServiceAccount,
+    ApiKeyParameters,
     ArchiveStatus,
     Cloud,
     CloudDataBucketAccessMode,
@@ -44,10 +49,14 @@ from anyscale.client.openapi_client.models import (
     ComputeTemplate,
     ComputeTemplateConfig,
     ComputeTemplateQuery,
+    CreateCloudCollaborator,
     CreateComputeTemplate,
     CreateDataset,
     CreateExperimentalWorkspace,
     CreateInternalProductionJob,
+    CreateOrganizationInvitation,
+    CreateResourceQuota,
+    CreateUserProjectCollaborator,
     Dataset as InternalDataset,
     DatasetUpload,
     DecoratedComputeTemplate,
@@ -57,6 +66,12 @@ from anyscale.client.openapi_client.models import (
     FineTunedModel,
     FinetunedmodelListResponse,
     InternalProductionJob,
+    ListResourceQuotasQuery,
+    OrganizationCollaborator,
+    OrganizationInvitation,
+    ResourceQuota,
+    ResourceQuotaStatus,
+    ServerSessionToken,
     SessionSshKey,
     StartSessionOptions,
     StopSessionOptions,
@@ -541,6 +556,14 @@ class AnyscaleClient(AnyscaleClientInterface):
 
             raise e from None
 
+    @handle_api_exceptions
+    def add_cloud_collaborators(
+        self, cloud_id: str, collaborators: List[CreateCloudCollaborator]
+    ) -> None:
+        self._internal_api_client.batch_create_cloud_collaborators_api_v2_clouds_cloud_id_collaborators_users_batch_create_post(
+            cloud_id, collaborators
+        )
+
     @handle_api_exceptions
     def create_compute_config(
         self, config: ComputeTemplateConfig, *, name: Optional[str] = None
@@ -983,6 +1006,14 @@ class AnyscaleClient(AnyscaleClientInterface):
             project_id
         ).result
 
+    @handle_api_exceptions
+    def add_project_collaborators(
+        self, project_id: str, collaborators: List[CreateUserProjectCollaborator]
+    ) -> None:
+        self._internal_api_client.batch_create_project_collaborators_api_v2_projects_project_id_collaborators_users_batch_create_post(
+            project_id, collaborators
+        )
+
     @handle_api_exceptions
     def get_job(
         self,
@@ -1064,6 +1095,11 @@ class AnyscaleClient(AnyscaleClientInterface):
         result: ServiceModel = self._external_api_client.terminate_service(service_id)
         return result
 
+    @handle_api_exceptions
+    def archive_service(self, service_id: str) -> ServiceModel:
+        result: ServiceModel = self._external_api_client.archive_service(service_id)
+        return result
+
     @handle_api_exceptions
     def submit_job(self, model: CreateInternalProductionJob) -> InternalProductionJob:
         job: InternalProductionJob = self._internal_api_client.create_job_api_v2_decorated_ha_jobs_create_post(
@@ -1119,10 +1155,10 @@ class AnyscaleClient(AnyscaleClientInterface):
                 # If the presigned URL scheme is SMART_OPEN, upload to cloud storage using the provided bucket name, path, & environment, and the smart_open library.
                 bucket_name = info.bucket_name
                 bucket_path = info.bucket_path
+
                 env_vars: Dict[str, str] = {
                     "AWS_ENDPOINT_URL": info.url,
                 }
-
                 with set_env(**env_vars), smart_open.open(
                     f"{bucket_name}/{bucket_path}", "wb",
                 ) as fout:
@@ -1131,7 +1167,14 @@ class AnyscaleClient(AnyscaleClientInterface):
             else:
                 # Default to HTTP PUT.
                 internal_logger.debug(f"Uploading file '{file_name}' to cloud storage.")
-                requests.put(info.url, data=zip_file_bytes).raise_for_status()
+                headers = (
+                    {"x-ms-blob-type": "BlockBlob"}
+                    if info.file_uri.startswith("azure")
+                    else None
+                )
+                requests.put(
+                    info.url, data=zip_file_bytes, headers=headers
+                ).raise_for_status()
 
         return info.file_uri
 
@@ -1758,3 +1801,208 @@ class AnyscaleClient(AnyscaleClientInterface):
             paging_token = resp.metadata.next_paging_token
 
         return results[:max_items] if max_items else results
+
+    @handle_api_exceptions
+    def download_aggregated_instance_usage_csv(
+        self,
+        start_date,
+        end_date,
+        cloud_id=None,
+        project_id=None,
+        directory=None,
+        hide_progress_bar=False,
+    ) -> str:
+        with FileDownloadProgress() as progress:
+            task_id = progress.add_task(
+                description="Preparing aggregated instance usage CSV",
+                visible=not hide_progress_bar,
+            )
+
+            resp = self._internal_api_client.download_aggregated_instance_usage_csv_api_v2_aggregated_instance_usage_download_csv_get(
+                start_date=start_date,
+                end_date=end_date,
+                cloud_id=cloud_id,
+                project_id=project_id,
+                _preload_content=False,
+            )
+
+            progress.update(
+                task_id, description="Downloading aggregated instance usage CSV"
+            )
+
+            # Set the total size of the download for the progress bar
+            total_size = int(resp.headers.get("content-length", 0))
+            progress.update(task_id, total=total_size)
+
+            # Construct the filepath to save the downloaded file
+            content_disposition = resp.headers.get("content-disposition", "")
+            filename_regex = re.search(
+                r'filename="?(?P<filename>[^"]+)"?', content_disposition
+            )
+
+            if not filename_regex:
+                filename = f"aggregated_instance_usage_{start_date}_{end_date}.zip"
+            else:
+                filename = filename_regex.group("filename")
+
+            if directory:
+                filepath = os.path.join(directory, filename)
+            else:
+                filepath = filename
+
+            # Download the file
+            try:
+                with open(filepath, "wb") as f:
+                    for chunk in resp.stream(Bytes.MB):
+                        if chunk:
+                            f.write(chunk)
+                            progress.update(task_id, advance=len(chunk))
+            except Exception as e:  # noqa: BLE001
+                raise ValueError(f"Failed to download to '{filepath}': {e}") from None
+
+            progress.update(task_id, completed=total_size)
+            progress.console.print(
+                f"Download complete! File saved to '{filepath}'",
+                style=Style(bold=True, color="green"),
+            )
+
+        return filepath
+
+    @handle_api_exceptions
+    def create_api_key(
+        self, duration: float, user_id: Optional[str]
+    ) -> ServerSessionToken:
+        return self._internal_api_client.create_api_key_api_v2_users_create_api_key_post(
+            ApiKeyParameters(user_id=user_id, duration=duration)
+        ).result
+
+    @handle_api_exceptions
+    def rotate_api_key(self, user_id: str) -> None:
+        self._internal_api_client.rotate_api_key_for_user_api_v2_organization_collaborators_rotate_api_key_for_user_user_id_post(
+            user_id
+        )
+
+    @handle_api_exceptions
+    def admin_batch_create_users(
+        self, admin_create_users: List[AdminCreateUser]
+    ) -> List[AdminCreatedUser]:
+        return self._internal_api_client.admin_batch_create_users_api_v2_users_admin_batch_create_post(
+            admin_create_users
+        ).results
+
+    @handle_api_exceptions
+    def create_organization_invitations(
+        self, emails: List[str]
+    ) -> Tuple[List[str], List[str]]:
+        results = self._internal_api_client.batch_create_invitations_api_v2_organization_invitations_batch_create_post(
+            [CreateOrganizationInvitation(email=email) for email in emails]
+        ).results
+
+        success_emails = []
+        error_messages = []
+
+        for idx, result in enumerate(results):
+            if result.data:
+                success_emails.append(emails[idx])
+            else:
+                error_messages.append(result.error.detail)
+
+        return success_emails, error_messages
+
+    @handle_api_exceptions
+    def list_organization_invitations(self) -> List[OrganizationInvitation]:
+        results = (
+            self._internal_api_client.list_invitations_api_v2_organization_invitations_get().results
+        )
+
+        return results
+
+    @handle_api_exceptions
+    def delete_organization_invitation(self, email: str) -> OrganizationInvitation:
+        invitation = self._internal_api_client.list_invitations_api_v2_organization_invitations_get(
+            email=email
+        ).results
+
+        if len(invitation) == 0:
+            raise ValueError(f"Invitation for email '{email}' not found.")
+        elif len(invitation) > 1:
+            raise ValueError(
+                f"Multiple invitations found for email '{email}'. Please contact Anyscale support."
+            )
+
+        invitation_id = invitation[0].id
+
+        return self._internal_api_client.invalidate_invitation_api_v2_organization_invitations_invitation_id_invalidate_post(
+            invitation_id
+        ).result
+
+    @handle_api_exceptions
+    def get_organization_collaborators(
+        self,
+        email: Optional[str] = None,
+        name: Optional[str] = None,
+        is_service_account: Optional[bool] = None,
+    ) -> List[OrganizationCollaborator]:
+        results = self._internal_api_client.list_organization_collaborators_api_v2_organization_collaborators_get(
+            email=email, name=name, is_service_account=is_service_account
+        ).results
+
+        return results
+
+    @handle_api_exceptions
+    def delete_organization_collaborator(self, identity_id: str) -> None:
+        self._internal_api_client.remove_organization_collaborator_api_v2_organization_collaborators_identity_id_delete(
+            identity_id
+        )
+
+    @handle_api_exceptions
+    def create_service_account(self, name: str) -> AnyscaleServiceAccount:
+        return self._internal_api_client.create_service_account_api_v2_users_service_accounts_post(
+            name
+        ).result
+
+    @handle_api_exceptions
+    def create_resource_quota(
+        self, create_resource_quota: CreateResourceQuota
+    ) -> ResourceQuota:
+        return self._internal_api_client.create_resource_quota_api_v2_resource_quotas_post(
+            create_resource_quota
+        ).result
+
+    @handle_api_exceptions
+    def list_resource_quotas(
+        self,
+        name: Optional[str] = None,
+        cloud_id: Optional[str] = None,
+        creator_id: Optional[str] = None,
+        is_enabled: Optional[bool] = None,
+        max_items: int = 20,
+    ) -> List[ResourceQuota]:
+
+        query = ListResourceQuotasQuery(
+            name=TextQuery(equals=name) if name else None,
+            cloud_id=cloud_id,
+            creator_id=creator_id,
+            is_enabled=is_enabled,
+            paging=PageQuery(count=max_items),
+        )
+
+        resource_quotas = self._internal_api_client.search_resource_quotas_api_v2_resource_quotas_search_post(
+            query
+        ).results
+
+        return resource_quotas
+
+    @handle_api_exceptions
+    def delete_resource_quota(self, resource_quota_id: str) -> None:
+        self._internal_api_client.delete_resource_quota_api_v2_resource_quotas_resource_quota_id_delete(
+            resource_quota_id
+        )
+
+    @handle_api_exceptions
+    def set_resource_quota_status(
+        self, resource_quota_id: str, is_enabled: bool
+    ) -> None:
+        self._internal_api_client.set_resource_quota_status_api_v2_resource_quotas_resource_quota_id_status_patch(
+            resource_quota_id, ResourceQuotaStatus(is_enabled=is_enabled)
+        ).result
