@@ -1,17 +1,28 @@
 from abc import ABC, abstractmethod
+from datetime import date
 from typing import Dict, Generator, List, Optional, Tuple
 
 from anyscale._private.models.image_uri import ImageURI
 from anyscale.client.openapi_client.models import (
+    AdminCreatedUser,
+    AdminCreateUser,
+    AnyscaleServiceAccount,
     Cloud,
     ComputeTemplateConfig,
+    CreateCloudCollaborator,
     CreateExperimentalWorkspace,
     CreateInternalProductionJob,
+    CreateResourceQuota,
+    CreateUserProjectCollaborator,
     DecoratedComputeTemplate,
     DeletedPlatformFineTunedModel,
     FineTunedModel,
     InternalProductionJob,
+    OrganizationCollaborator,
+    OrganizationInvitation,
     Project,
+    ResourceQuota,
+    ServerSessionToken,
     WorkspaceDataplaneProxiedArtifacts,
 )
 from anyscale.client.openapi_client.models.create_schedule import CreateSchedule
@@ -38,7 +49,7 @@ from anyscale.utils.workspace_notification import WorkspaceNotification
 # Maybe just make it part of the release process to update it, or fetch the
 # default builds and get the latest one. The best thing to do is probably
 # to populate this in the backend.
-DEFAULT_RAY_VERSION = "2.38.0"  # RAY_RELEASE_UPDATE: update to latest version.
+DEFAULT_RAY_VERSION = "2.41.0"  # RAY_RELEASE_UPDATE: update to latest version.
 DEFAULT_PYTHON_VERSION = "py311"
 RUNTIME_ENV_PACKAGE_FORMAT = "pkg_{content_hash}.zip"
 
@@ -139,6 +150,13 @@ class AnyscaleClientInterface(ABC):
         """
         raise NotImplementedError
 
+    @abstractmethod
+    def add_cloud_collaborators(
+        self, cloud_id: str, collaborators: List[CreateCloudCollaborator]
+    ) -> None:
+        """Batch add collaborators to a cloud."""
+        raise NotImplementedError
+
     @abstractmethod
     def create_compute_config(
         self, config: ComputeTemplateConfig, *, name: Optional[str] = None
@@ -282,6 +300,13 @@ class AnyscaleClientInterface(ABC):
         """
         raise NotImplementedError
 
+    @abstractmethod
+    def add_project_collaborators(
+        self, project_id: str, collaborators: List[CreateUserProjectCollaborator]
+    ) -> None:
+        """Batch add collaborators to a project."""
+        raise NotImplementedError
+
     @abstractmethod
     def get_job(
         self,
@@ -328,6 +353,11 @@ class AnyscaleClientInterface(ABC):
         """Mark the service to be terminated asynchronously."""
         raise NotImplementedError
 
+    @abstractmethod
+    def archive_service(self, service_id: str):
+        """Mark the service to be archived asynchronously."""
+        raise NotImplementedError
+
     @abstractmethod
     def submit_job(self, model: CreateInternalProductionJob) -> InternalProductionJob:
         """Submit the job to run."""
@@ -577,3 +607,103 @@ class AnyscaleClientInterface(ABC):
     ):
         """Update a workspace."""
         raise NotImplementedError
+
+    @abstractmethod
+    def download_aggregated_instance_usage_csv(
+        self,
+        start_date: date,
+        end_date: date,
+        cloud_id: Optional[str] = None,
+        project_id: Optional[str] = None,
+        directory: Optional[str] = None,
+        hide_progress_bar: bool = False,
+    ) -> str:
+        """Download the aggregated instance usage csv."""
+        raise NotImplementedError
+
+    @abstractmethod
+    def create_api_key(
+        self, duration: float, user_id: Optional[str]
+    ) -> ServerSessionToken:
+        """Create a new API key."""
+        raise NotImplementedError
+
+    @abstractmethod
+    def rotate_api_key(self, user_id: str) -> None:
+        """Rotate the API key for user."""
+        raise NotImplementedError
+
+    @abstractmethod
+    def admin_batch_create_users(
+        self, admin_create_users: List[AdminCreateUser]
+    ) -> List[AdminCreatedUser]:
+        """Batch create, as an admin, users without email verification."""
+        raise NotImplementedError
+
+    @abstractmethod
+    def create_organization_invitations(
+        self, emails: List[str]
+    ) -> Tuple[List[str], List[str]]:
+        """Create organization invitations."""
+        raise NotImplementedError
+
+    @abstractmethod
+    def list_organization_invitations(self) -> List[OrganizationInvitation]:
+        """List organization invitations."""
+        raise NotImplementedError
+
+    @abstractmethod
+    def delete_organization_invitation(self, email: str) -> OrganizationInvitation:
+        """Delete organization invitation."""
+        raise NotImplementedError
+
+    @abstractmethod
+    def get_organization_collaborators(
+        self,
+        email: Optional[str] = None,
+        name: Optional[str] = None,
+        is_service_account: Optional[bool] = None,
+    ) -> List[OrganizationCollaborator]:
+        """Get organization collaborators."""
+        raise NotImplementedError
+
+    @abstractmethod
+    def delete_organization_collaborator(self, identity_id: str) -> None:
+        """Delete organization collaborator."""
+        raise NotImplementedError
+
+    @abstractmethod
+    def create_service_account(self, name: str) -> AnyscaleServiceAccount:
+        """Create a service account."""
+        raise NotImplementedError
+
+    @abstractmethod
+    def create_resource_quota(
+        self, create_resource_quota: CreateResourceQuota
+    ) -> ResourceQuota:
+        """Create a resource quota."""
+        raise NotImplementedError
+
+    @abstractmethod
+    def list_resource_quotas(
+        self,
+        name: Optional[str] = None,
+        cloud_id: Optional[str] = None,
+        creator_id: Optional[str] = None,
+        is_enabled: Optional[bool] = None,
+        max_items: int = 20,
+    ) -> List[ResourceQuota]:
+        """List resource quotas."""
+        raise NotImplementedError
+
+    @abstractmethod
+    def delete_resource_quota(self, resource_quota_id: str) -> None:
+        """Delete a resource quota."""
+        raise NotImplementedError
+
+    @abstractmethod
+    def set_resource_quota_status(
+        self, resource_quota_id: str, is_enabled: bool
+    ) -> None:
+        """Set the status of a resource quota."""
+        raise NotImplementedError
