@@ -1,6 +1,7 @@
 from collections import defaultdict
-from datetime import datetime
+from datetime import date, datetime
 import logging
+import os
 from typing import DefaultDict, Dict, Generator, List, Optional, Tuple
 from unittest.mock import Mock
 import uuid
@@ -13,10 +14,17 @@ from anyscale._private.models.image_uri import ImageURI
 from anyscale._private.models.model_base import ListResponse
 from anyscale.cli_logger import BlockLogger
 from anyscale.client.openapi_client.models import (
+    AdminCreatedUser,
+    AdminCreateUser,
+    AnyscaleServiceAccount,
     Cloud,
+    CloudProviders,
     ComputeTemplateConfig,
+    CreateCloudCollaborator,
     CreateExperimentalWorkspace,
     CreateInternalProductionJob,
+    CreateResourceQuota,
+    CreateUserProjectCollaborator,
     DecoratedComputeTemplate,
     DeletedPlatformFineTunedModel,
     ExperimentalWorkspace,
@@ -25,9 +33,16 @@ from anyscale.client.openapi_client.models import (
     HaJobGoalStates,
     HaJobStates,
     InternalProductionJob,
+    MiniCloud,
+    MiniUser,
+    OrganizationCollaborator,
+    OrganizationInvitation,
+    OrganizationPermissionLevel,
     ProductionJob,
     ProductionJobStateTransition,
     Project,
+    ResourceQuota,
+    ServerSessionToken,
     WorkspaceDataplaneProxiedArtifacts,
 )
 from anyscale.client.openapi_client.models.create_schedule import CreateSchedule
@@ -129,9 +144,11 @@ class FakeAnyscaleClient(AnyscaleClientInterface):
         self._workspace_cluster: Optional[Cluster] = None
         self._workspace_dependency_tracking_enabled: bool = False
         self._services: Dict[str, ServiceModel] = {}
+        self._archived_services: Dict[str, ServiceModel] = {}
         self._jobs: Dict[str, ProductionJob] = {}
         self._job_runs: Dict[str, List[APIJobRun]] = defaultdict(list)
         self._project_to_id: Dict[Optional[str] : Dict[Optional[str], str]] = {}
+        self._project_collaborators: Dict[str, List[CreateUserProjectCollaborator]] = {}
         self._rolled_out_model: Optional[ApplyServiceModel] = None
         self._sent_workspace_notifications: List[WorkspaceNotification] = []
         self._rolled_back_service: Optional[Tuple[str, Optional[int]]] = None
@@ -145,11 +162,16 @@ class FakeAnyscaleClient(AnyscaleClientInterface):
         self._controller_logs: Dict[str, str] = {}
         self._schedules: Dict[str, DecoratedSchedule] = {}
         self._schedule_trigger_counts: Dict[str, int] = defaultdict(int)
+        self._users: Dict[str, AdminCreatedUser] = {}
         self._workspaces: Dict[str, ExperimentalWorkspace] = {}
         self._workspaces_dependencies: Dict[str, List[str]] = {}
         self._workspaces_env_vars: Dict[str, Dict[str, str]] = {}
         self._clusters_headnode_ip: Dict[str, str] = {}
         self._clusters_ssh_key: Dict[str, SessionSshKey] = {}
+        self._api_keys: Dict[str, List[str]] = defaultdict(list)
+        self._organization_collaborators: List[OrganizationCollaborator] = []
+        self._organization_invitations: Dict[str, OrganizationInvitation] = {}
+        self._resource_quotas: Dict[str, ResourceQuota] = {}
 
         # Cloud ID -> Cloud.
         self._clouds: Dict[str, Cloud] = {
@@ -160,6 +182,9 @@ class FakeAnyscaleClient(AnyscaleClientInterface):
             ),
         }
 
+        # Cloud ID -> collaborators
+        self._cloud_collaborators: Dict[str, List[CreateCloudCollaborator]] = {}
+
         # Cloud ID -> default ClusterCompute.
         compute_config = ClusterCompute(
             id=self.DEFAULT_CLUSTER_COMPUTE_ID,
@@ -343,6 +368,25 @@ class FakeAnyscaleClient(AnyscaleClientInterface):
     def get_cloud(self, *, cloud_id: str) -> Optional[Cloud]:
         return self._clouds.get(cloud_id, None)
 
+    def add_cloud_collaborators(
+        self, cloud_id: str, collaborators: List[CreateCloudCollaborator]
+    ) -> None:
+        existing_collaborators = [
+            collaborator.email
+            for collaborator in self._cloud_collaborators.get(cloud_id, [])
+        ]
+
+        for collaborator in collaborators:
+            if collaborator.email in existing_collaborators:
+                raise ValueError(
+                    f"Collaborator with email '{collaborator.email}' already exists in cloud '{cloud_id}'."
+                )
+
+        if cloud_id not in self._cloud_collaborators:
+            self._cloud_collaborators[cloud_id] = collaborators
+        else:
+            self._cloud_collaborators[cloud_id].extend(collaborators)
+
     def add_compute_config(self, compute_config: DecoratedComputeTemplate) -> int:
         compute_config.version = (
             len(self._compute_config_name_to_ids[compute_config.name]) + 1
@@ -575,6 +619,28 @@ class FakeAnyscaleClient(AnyscaleClientInterface):
                     )
         return None
 
+    def add_project_collaborators(
+        self, project_id: str, collaborators: List[CreateUserProjectCollaborator]
+    ):
+        existing_collaborators = [
+            collaborator.value.email if collaborator.value else None
+            for collaborator in self._project_collaborators.get(project_id, [])
+        ]
+
+        for collaborator in collaborators:
+            if (
+                collaborator.value
+                and collaborator.value.email in existing_collaborators
+            ):
+                raise ValueError(
+                    f"Collaborator with email '{collaborator.value.email}' already exists in project '{project_id}'."
+                )
+
+        if project_id not in self._project_collaborators:
+            self._project_collaborators[project_id] = collaborators
+        else:
+            self._project_collaborators[project_id].extend(collaborators)
+
     def get_job(
         self,
         *,
@@ -698,6 +764,16 @@ class FakeAnyscaleClient(AnyscaleClientInterface):
                 service_id
             ].primary_version.current_state = ServiceVersionState.TERMINATED
 
+    @property
+    def archived_services(self) -> Dict[str, ServiceModel]:
+        return self._archived_services
+
+    def archive_service(self, service_id: str):
+        self._archived_services[service_id] = self._services.pop(service_id)
+
+    def is_archived_service(self, service_id: str) -> bool:
+        return service_id in self._archived_services
+
     @property
     def submitted_job(self) -> Optional[CreateInternalProductionJob]:
         return self._submitted_job
@@ -904,7 +980,7 @@ class FakeAnyscaleClient(AnyscaleClientInterface):
             compute_config_id=model.compute_config_id,
             environment_id=model.cluster_environment_build_id,
             cloud_id=model.cloud_id or self.get_cloud_id(),
-            created_at=datetime.now(),
+            created_at=datetime.utcnow(),
             creator_id=self.DEFAULT_USER_ID,
             creator_email=self.DEFAULT_USER_EMAIL,
             organization_id=self.DEFAULT_ORGANIZATION_ID,
@@ -1060,3 +1136,211 @@ class FakeAnyscaleClient(AnyscaleClientInterface):
             compute_config = self.get_compute_config(workspace.compute_config_id)
             assert compute_config is not None
             compute_config.idle_timeout_minutes = idle_timeout_minutes
+
+    def download_aggregated_instance_usage_csv(
+        self,
+        start_date: date,
+        end_date: date,
+        cloud_id: Optional[str] = None,  # noqa: ARG002
+        project_id: Optional[str] = None,  # noqa: ARG002
+        directory: Optional[str] = None,
+        hide_progress_bar: bool = False,  # noqa: ARG002
+    ) -> str:
+        filename = f"aggregated_instance_usage_{start_date}_{end_date}.zip"
+        if directory:
+            filepath = os.path.join(directory, filename)
+        else:
+            filepath = filename
+
+        return filepath
+
+    def create_api_key(
+        self, duration: float, user_id: Optional[str]  # noqa: ARG002
+    ) -> ServerSessionToken:
+        api_key = f"{uuid.uuid4()!s}"
+        api_keys = self._api_keys.get(user_id or "usr_1", [])
+        self._api_keys[user_id or "usr_1"] = api_keys + [api_key]
+
+        return ServerSessionToken(server_session_id=api_key)
+
+    def rotate_api_key(self, user_id: str) -> None:
+        if user_id not in self._api_keys:
+            raise ValueError(f"User '{user_id}' not found.")
+        self._api_keys[user_id] = [f"{uuid.uuid4()!s}"]
+
+    def admin_batch_create_users(
+        self, admin_create_users: List[AdminCreateUser]
+    ) -> List[AdminCreatedUser]:
+        created_users = []
+        for admin_create_user in admin_create_users:
+            if admin_create_user.email in self._users:
+                raise ValueError(
+                    f"User with email '{admin_create_user.email}' already exists."
+                )
+
+            user_id = f"user-id-{uuid.uuid4()!s}"
+            created_user = AdminCreatedUser(
+                user_id=user_id,
+                email=admin_create_user.email,
+                created_at=datetime.utcnow(),
+                name=admin_create_user.name,
+                lastname=admin_create_user.lastname,
+                title=admin_create_user.title,
+                is_sso_user=admin_create_user.is_sso_user,
+            )
+            created_users.append(created_user)
+            self._users[admin_create_user.email] = created_user
+
+        return created_users
+
+    def create_organization_invitations(
+        self, emails: List[str]
+    ) -> Tuple[List[str], List[str]]:
+        success_emails, error_messages = [], []
+        for email in emails:
+            if email in self._users:
+                error_messages.append(
+                    f"User with email {email} is already a member of your organization."
+                )
+            else:
+                orginv_id = f"orginv_{uuid.uuid4()!s}"
+                self._organization_invitations[email] = OrganizationInvitation(
+                    email=email,
+                    id=orginv_id,
+                    organization_id="org_1",
+                    created_at=datetime.utcnow(),
+                    expires_at=datetime.utcnow(),
+                )
+                success_emails.append(email)
+
+        return success_emails, error_messages
+
+    def list_organization_invitations(self) -> List[OrganizationInvitation]:
+        return list(self._organization_invitations.values())
+
+    def delete_organization_invitation(self, email: str) -> OrganizationInvitation:
+        if email not in self._organization_invitations:
+            raise ValueError(f"Invitation for email '{email}' not found.")
+
+        return self._organization_invitations.pop(email)
+
+    def get_organization_collaborators(
+        self,
+        email: Optional[str] = None,
+        name: Optional[str] = None,
+        is_service_account: Optional[bool] = None,  # noqa: ARG002
+    ) -> List[OrganizationCollaborator]:
+        # Since organization collaborator doesn't include whether it's a service account or not, we'll just return all
+        results = []
+        for organization_collaborator in self._organization_collaborators:
+            if email and organization_collaborator.email != email:
+                continue
+            if name and organization_collaborator.name != name:
+                continue
+
+            results.append(organization_collaborator)
+
+        return results
+
+    def delete_organization_collaborator(self, identity_id: str) -> None:
+        for organization_collaborator in self._organization_collaborators:
+            if organization_collaborator.id == identity_id:
+                self._organization_collaborators.remove(organization_collaborator)
+                return
+
+        raise ValueError(
+            f"Organization collaborator with id '{identity_id}' not found."
+        )
+
+    def create_service_account(self, name) -> AnyscaleServiceAccount:
+        for organization_collaborator in self._organization_collaborators:
+            if organization_collaborator.name == name:
+                raise ValueError(f"Service account with name '{name}' already exists.")
+
+        identity_id = f"id_{uuid.uuid4()!s}"
+        user_id = f"usr_{uuid.uuid4()!s}"
+        organization_collaborator = OrganizationCollaborator(
+            permission_level=OrganizationPermissionLevel.COLLABORATOR,
+            id=identity_id,
+            name=name,
+            email=f"{name}@service-account.com",
+            user_id=user_id,
+            created_at=datetime.utcnow(),
+        )
+
+        self._organization_collaborators.append((organization_collaborator))
+
+        return AnyscaleServiceAccount(
+            user_id=organization_collaborator.user_id,
+            name=organization_collaborator.name,
+            organization_id="org_1",
+            email=organization_collaborator.email,
+            permission_level=organization_collaborator.permission_level,
+            created_at=organization_collaborator.created_at,
+        )
+
+    def create_resource_quota(
+        self, create_resource_quota: CreateResourceQuota
+    ) -> ResourceQuota:
+        resource_quota_id = f"rq_{uuid.uuid4()!s}"
+        resource_quota = ResourceQuota(
+            id=resource_quota_id,
+            name=create_resource_quota.name,
+            cloud_id=create_resource_quota.cloud_id,
+            project_id=create_resource_quota.project_id,
+            quota=create_resource_quota.quota,
+            is_enabled=True,
+            created_at=datetime.utcnow(),
+            creator=MiniUser(
+                id="user_1",
+                email="test@anyscale.com",
+                name="Test User",
+                username="testuser",
+            ),
+            cloud=MiniCloud(
+                id=create_resource_quota.cloud_id,
+                name="Test Cloud",
+                provider=CloudProviders.AWS,
+            ),
+        )
+
+        self._resource_quotas[resource_quota_id] = resource_quota
+
+        return self._resource_quotas[resource_quota_id]
+
+    def list_resource_quotas(
+        self,
+        name: Optional[str] = None,
+        cloud_id: Optional[str] = None,
+        creator_id: Optional[str] = None,
+        is_enabled: Optional[bool] = None,
+        max_items: int = 20,
+    ) -> List[ResourceQuota]:
+        results = []
+        for resource_quota in self._resource_quotas.values():
+            if name and resource_quota.name != name:
+                continue
+            if cloud_id and resource_quota.cloud_id != cloud_id:
+                continue
+            if creator_id and resource_quota.creator.id != creator_id:
+                continue
+            if is_enabled is not None and resource_quota.is_enabled != is_enabled:
+                continue
+            results.append(resource_quota)
+
+        return results[:max_items]
+
+    def delete_resource_quota(self, resource_quota_id: str) -> None:
+        if resource_quota_id not in self._resource_quotas:
+            raise ValueError(f"Resource Quota with id '{resource_quota_id}' not found.")
+
+        self._resource_quotas.pop(resource_quota_id)
+
+    def set_resource_quota_status(
+        self, resource_quota_id: str, is_enabled: bool
+    ) -> None:
+        resource_quota = self._resource_quotas.get(resource_quota_id)
+        if resource_quota is None:
+            raise ValueError(f"Resource Quota with id '{resource_quota_id}' not found.")
+
+        resource_quota.is_enabled = is_enabled
