@@ -9,7 +9,13 @@ import click
 import anyscale
 from anyscale import scripts
 from anyscale._private.docgen.generator import MarkdownGenerator, Module
+from anyscale.aggregated_instance_usage.models import DownloadCSVFilters
+from anyscale.cloud.models import (
+    CloudPermissionLevel,
+    CreateCloudCollaborator,
+)
 from anyscale.commands import (
+    aggregated_instance_usage_commands,
     cloud_commands,
     cluster_commands,
     cluster_env_commands,
@@ -20,11 +26,13 @@ from anyscale.commands import (
     logs_commands,
     machine_commands,
     machine_pool_commands,
+    organization_invitation_commands,
     project_commands,
     resource_quota_commands,
     schedule_commands,
     service_account_commands,
     service_commands,
+    user_commands,
     workspace_commands,
     workspace_commands_v2,
 )
@@ -55,6 +63,9 @@ from anyscale.llm.model.models import (
     FineTunedModel,
     FineTuningType,
 )
+from anyscale.organization_invitation.models import OrganizationInvitation
+from anyscale.project.models import CreateProjectCollaborator, ProjectPermissionLevel
+from anyscale.resource_quota.models import CreateResourceQuota, Quota, ResourceQuota
 from anyscale.schedule.models import ScheduleConfig, ScheduleState, ScheduleStatus
 from anyscale.service.models import (
     RayGCSExternalStorageConfig,
@@ -65,11 +76,57 @@ from anyscale.service.models import (
     ServiceVersionStatus,
     TracingConfig,
 )
+from anyscale.service_account.models import OrganizationPermissionLevel, ServiceAccount
+from anyscale.user.models import AdminCreatedUser, AdminCreateUser
 from anyscale.workspace.models import WorkspaceConfig
 
 
 # Defines all modules to be documented.
 ALL_MODULES = [
+    Module(
+        title="Aggregated Instance Usage",
+        filename="aggregated-instance-usage.md",
+        cli_prefix="anyscale aggregated-instance-usage",
+        cli_commands=[aggregated_instance_usage_commands.download_csv],
+        sdk_prefix="anyscale.aggregated_instance_usage",
+        sdk_commands=[anyscale.aggregated_instance_usage.download_csv,],
+        models=[DownloadCSVFilters],
+    ),
+    Module(
+        title="User",
+        filename="user.md",
+        cli_prefix="user",
+        cli_commands=[user_commands.admin_batch_create],
+        sdk_prefix="anyscale.user",
+        sdk_commands=[anyscale.user.admin_batch_create,],
+        models=[AdminCreateUser, AdminCreatedUser],
+    ),
+    Module(
+        title="Project",
+        filename="project-api.md",
+        cli_prefix="anyscale project",
+        cli_commands=[project_commands.add_collaborators,],
+        sdk_prefix="anyscale.project",
+        sdk_commands=[anyscale.project.add_collaborators,],
+        models=[ProjectPermissionLevel, CreateProjectCollaborator],
+        legacy_cli_commands=[project_commands.create, project_commands.list,],
+        legacy_sdk_commands={
+            "create_project": None,
+            "delete_project": None,
+            "get_default_project": None,
+            "get_project": None,
+            "search_projects": None,
+            "update_project": None,
+        },
+        legacy_sdk_models=[
+            "CreateProject",
+            "Project",
+            "ProjectListResponse",
+            "ProjectResponse",
+            "ProjectsQuery",
+            "UpdateProject",
+        ],
+    ),
     Module(
         title="Job",
         filename="job-api.md",
@@ -300,8 +357,14 @@ ALL_MODULES = [
             service_account_commands.rotate_api_keys,
         ],
         sdk_prefix="anyscale.service_account",
-        sdk_commands=[],
-        models=[],
+        sdk_commands=[
+            anyscale.service_account.create,
+            anyscale.service_account.create_api_key,
+            anyscale.service_account.list,
+            anyscale.service_account.delete,
+            anyscale.service_account.rotate_api_keys,
+        ],
+        models=[ServiceAccount, OrganizationPermissionLevel],
     ),
     Module(
         title="Image",
@@ -378,10 +441,12 @@ ALL_MODULES = [
             cloud_commands.cloud_verify,
             cloud_commands.list_cloud,
             cloud_commands.cloud_config_update,
+            cloud_commands.cloud_set_default,
+            cloud_commands.add_collaborators,
         ],
         sdk_prefix="anyscale.cloud",
-        sdk_commands=[],
-        models=[],
+        sdk_commands=[anyscale.cloud.add_collaborators],
+        models=[CloudPermissionLevel, CreateCloudCollaborator],
         cli_command_group_prefix={cloud_commands.cloud_config_update: "config"},
         legacy_sdk_commands={
             # limited support, no replacement yet
@@ -430,6 +495,8 @@ ALL_MODULES = [
             workspace_commands_v2.run_command,
             workspace_commands_v2.pull,
             workspace_commands_v2.push,
+            workspace_commands_v2.update,
+            workspace_commands_v2.get,
         ],
         sdk_prefix="anyscale.workspace",
         sdk_commands=[
@@ -555,8 +622,31 @@ ALL_MODULES = [
             resource_quota_commands.disable,
         ],
         sdk_prefix="anyscale.resource_quota",
-        sdk_commands=[],  # No SDK commands for resource quotas
-        models=[],
+        sdk_commands=[
+            anyscale.resource_quota.create,
+            anyscale.resource_quota.list,
+            anyscale.resource_quota.delete,
+            anyscale.resource_quota.enable,
+            anyscale.resource_quota.disable,
+        ],
+        models=[CreateResourceQuota, Quota, ResourceQuota],
+    ),
+    Module(
+        title="Organization Invitation",
+        filename="organization-invitation.md",
+        cli_prefix="anyscale organization-invitation",
+        cli_commands=[
+            organization_invitation_commands.create,
+            organization_invitation_commands.list,
+            organization_invitation_commands.delete,
+        ],
+        sdk_prefix="anyscale.organization-invitation",
+        sdk_commands=[
+            anyscale.organization_invitation.create,
+            anyscale.organization_invitation.list,
+            anyscale.organization_invitation.delete,
+        ],
+        models=[OrganizationInvitation],
     ),
     Module(
         title="Other",
@@ -575,52 +665,33 @@ ALL_MODULES = [
         legacy_cli_commands=[
             machine_commands.delete_machine,
             machine_commands.list_machines,
-            project_commands.create,
-            project_commands.list,
         ],
         legacy_sdk_commands={
             "get_organization_temporary_object_storage_credentials": None,
             "partial_update_organization": None,
-            "create_project": None,
-            "delete_project": None,
-            "get_default_project": None,
-            "get_project": None,
-            "search_projects": None,
-            "update_project": None,
             "get_runtime_environment": None,
             "create_session_command": None,
             "get_session_command": None,
             "list_session_commands": None,
-            "get_session_event_log": None,
             "upsert_sso_config": None,
             "upsert_test_sso_config": None,
         },
         legacy_sdk_models=[
-            "AWSNodeOptions",
-            "AWSTag",
-            "AWSTagSpecification",
             "AccessConfig",
             "ArchiveStatus",
             "BASEIMAGESENUM",
             "BaseJobStatus",
-            "BlockDeviceMapping",
             "Build",
             "BuildListResponse",
             "BuildResponse",
             "BuildStatus",
             "CreateBuild",
-            "CreateProject",
             "CreateSSOConfig",
-            "EbsBlockDevice",
-            "GCPNodeDisk",
-            "GCPNodeOptions",
             "GrpcProtocolConfig",
             "HTTPValidationError",
             "HttpProtocolConfig",
-            "IamInstanceProfileSpecification",
             "IdleTerminationStatus",
             "ListResponseMetadata",
-            "NetworkInterface",
             "NodeType",
             "ObjectStorageConfig",
             "ObjectStorageConfigS3",
@@ -631,10 +702,6 @@ ALL_MODULES = [
             "Organization",
             "OrganizationResponse",
             "PageQuery",
-            "Project",
-            "ProjectListResponse",
-            "ProjectResponse",
-            "ProjectsQuery",
             "Protocols",
             "PythonModules",
             "PythonVersion",
@@ -649,7 +716,6 @@ ALL_MODULES = [
             "TextQuery",
             "TracingConfig",
             "UpdateOrganization",
-            "UpdateProject",
             "UserServiceAccessTypes",
             "WorkerNodeType",
         ],
