@@ -26,6 +26,7 @@ CLI_NO_EXAMPLES = {
     "anyscale",
     "anyscale cloud",
     "anyscale cloud config",
+    "anyscale cloud set-default",
     "anyscale logs",
     "anyscale service-account",
     "anyscale service",
@@ -178,10 +179,11 @@ class MarkdownGenerator:
             output = f"## {m.title} CLI\n"
 
         for t in commands or []:
+            cli_command_prefix = cli_prefix
             if m.cli_command_group_prefix and t in m.cli_command_group_prefix:
-                cli_prefix = f"{cli_prefix} {m.cli_command_group_prefix[t]}"
+                cli_command_prefix = f"{cli_prefix} {m.cli_command_group_prefix[t]}"
             output += "\n" + self._gen_markdown_for_cli_command(
-                t, cli_prefix=cli_prefix or ""
+                t, cli_prefix=cli_command_prefix or ""
             )
 
         return output
