@@ -93,7 +93,7 @@ class WorkloadConfig(ModelBase):
         default=None,
         repr=False,
         metadata={
-            "docstring": "A list of pip requirements or a path to a `requirements.txt` file for the workload. When running inside a workspace, this defaults to the workspace-tracked requirements."
+            "docstring": "A list of pip requirements or a path to a `requirements.txt` file for the workload. Anyscale installs these dependencies on top of the image. If you run a workload from a workspace, the default is to use the workspace dependencies, but specifying this option overrides them."
         },
     )
 
@@ -117,13 +117,27 @@ class WorkloadConfig(ModelBase):
     )
 
     def _validate_env_vars(self, env_vars: Optional[Dict[str, str]]):
-        if env_vars is not None and (
-            not isinstance(env_vars, dict)
-            or not all(
-                isinstance(k, str) and isinstance(v, str) for k, v in env_vars.items()
+        if env_vars is None:
+            return
+
+        if not isinstance(env_vars, dict):
+            raise TypeError(
+                "'env_vars' must be a Dict[str, str], "
+                f"but got type {type(env_vars)}."
             )
-        ):
-            raise TypeError("'env_vars' must be a Dict[str, str].")
+
+        for k, v in env_vars.items():
+            if not isinstance(k, str):
+                raise TypeError(
+                    "'env_vars' must be a Dict[str, str], "
+                    f"but got key of type {type(k)}: {k}."
+                )
+
+            if not isinstance(v, str):
+                raise TypeError(
+                    "'env_vars' must be a Dict[str, str], "
+                    f"but got value of type {type(v)} for key '{k}': {v}."
+                )
 
     py_modules: Optional[List[str]] = field(
         default=None,
