@@ -47,6 +47,8 @@ from anyscale.utils.s3 import verify_s3_access
 DEFAULT_RAY_IAM_ROLE = "ray-autoscaler-v1"
 
 S3_ARN_PREFIX = "arn:aws:s3:::"
+S3_STORAGE_PREFIX = "s3://"
+GCS_STORAGE_PREFIX = "gs://"
 
 
 def compare_dicts_diff(d1: Dict[Any, Any], d2: Dict[Any, Any]) -> str:
