@@ -4,7 +4,7 @@ from typing import Optional, Tuple
 from anyscale.authenticate import get_auth_api_client
 from anyscale.cli_logger import BlockLogger
 from anyscale.client.openapi_client.api.default_api import DefaultApi
-from anyscale.cloud import get_cloud_id_and_name, get_last_used_cloud
+from anyscale.cloud_utils import get_cloud_id_and_name, get_last_used_cloud
 from anyscale.sdk.anyscale_client import (
     ArchiveStatus,
     ComputeTemplateConfig,
