@@ -1,15 +1,22 @@
+from io import StringIO
 import re
 from typing import List, Optional
 
 import click
+import yaml
 
+import anyscale
 from anyscale.cli_logger import BlockLogger
 from anyscale.client.openapi_client.models import ClusterManagementStackVersions
 from anyscale.client.openapi_client.models.compute_stack import ComputeStack
-from anyscale.commands import cloud_commands_util
-from anyscale.commands.util import OptionPromptNull
+from anyscale.cloud.models import CreateCloudCollaborator, CreateCloudCollaborators
+from anyscale.commands import cloud_commands_util, command_examples
+from anyscale.commands.util import AnyscaleCommand, OptionPromptNull
 from anyscale.controllers.cloud_controller import CloudController
-from anyscale.util import validate_non_negative_arg
+from anyscale.util import (
+    allow_optional_file_storage,
+    validate_non_negative_arg,
+)
 
 
 log = BlockLogger()  # CLI Logger
@@ -316,11 +323,12 @@ def cloud_config_get(
             "The positional argument CLOUD_NAME and the keyword argument --name "
             "were both provided. Please only provide one of these two arguments."
         )
-    print(
-        CloudController().get_cloud_config(
-            cloud_name=cloud_name or name, cloud_id=cloud_id,
-        )
+    config = CloudController().get_cloud_config(
+        cloud_name=cloud_name or name, cloud_id=cloud_id,
     )
+    stream = StringIO()
+    yaml.dump(config.spec, stream)
+    print(stream.getvalue())
 
 
 @cloud_config_group.command(
@@ -349,13 +357,26 @@ def cloud_config_get(
         "extra data transfer cost from the cloud provider by enabling this feature."
     ),
 )
+@click.option(
+    "--spec-file",
+    type=str,
+    required=False,
+    help="Provide a path to a specification file.",
+)
 def cloud_config_update(
     cloud_name: Optional[str],
     name: Optional[str],
     cloud_id: Optional[str],
     enable_log_ingestion: Optional[bool],
+    spec_file: Optional[str],
 ) -> None:
+    if any([enable_log_ingestion is not None]) and spec_file:
+        raise click.ClickException(
+            "Please provide only one of the following arguments: --enable-log-ingestion, --disable-log-ingestion, --spec-file."
+        )
+
     if any([enable_log_ingestion is not None]):
+        # TODO: enable_log_ingestion should be unified into cloud deployment config.
         if enable_log_ingestion is True:
             consent_message = click.prompt(
                 "--enable-log-ingestion is specified. Please note the logs produced by "
@@ -385,6 +406,10 @@ def cloud_config_update(
             cloud_id=cloud_id,
             enable_log_ingestion=enable_log_ingestion,
         )
+    elif spec_file:
+        CloudController().update_cloud_config(
+            cloud_name=cloud_name or name, cloud_id=cloud_id, spec_file=spec_file,
+        )
     else:
         raise click.ClickException(
             "Please provide at least one of the following arguments: --enable-log-ingestion, --disable-log-ingestion."
@@ -431,7 +456,13 @@ def cloud_config_update(
     type=str,
 )
 @click.option(
-    "--efs-id", help="The EFS ID.", required=False, type=str,
+    "--file-storage-id",
+    help="File storage ID (e.g. EFS ID for AWS, Filestore instance ID for GCP)",
+    required=False,
+    type=str,
+)
+@click.option(
+    "--efs-id", help="The EFS ID.", required=False, type=str, hidden=True,
 )
 @click.option(
     "--anyscale-iam-role-id",
@@ -452,7 +483,7 @@ def cloud_config_update(
     type=str,
 )
 @click.option(
-    "--s3-bucket-id", help="S3 bucket ID.", required=False, type=str,
+    "--s3-bucket-id", help="S3 bucket ID.", required=False, type=str, hidden=True,
 )
 @click.option(
     "--external-id",
@@ -483,6 +514,7 @@ def cloud_config_update(
     help="Filestore instance ID for GCP clouds.",
     required=False,
     type=str,
+    hidden=True,
 )
 @click.option(
     "--filestore-location",
@@ -526,6 +558,12 @@ def cloud_config_update(
     required=False,
     type=str,
 )
+@click.option(
+    "--cloud-storage-bucket-region",
+    help="The region of the cloud storage bucket. If not provided, the region of the cloud will be used to access the cloud storage bucket.",
+    required=False,
+    type=str,
+)
 @click.option(
     "--nfs-mount-target",
     help="A comma-separated value representing a (zone, mount target) tuple, e.g. us-west-2a,1.2.3.4 (may be provided multiple times, one for each zone). If only one value is provided (e.g. 1.2.3.4), then that value will be used for all zones.",
@@ -595,13 +633,14 @@ def cloud_config_update(
         "permissions after the cloud is created."
     ),
 )
-def register_cloud(  # noqa: PLR0913, PLR0912
+def register_cloud(  # noqa: PLR0913, PLR0912, C901
     provider: str,
     region: str,
     compute_stack: ComputeStack,
     name: str,
     vpc_id: str,
     subnet_ids: str,
+    file_storage_id: str,
     efs_id: str,
     anyscale_iam_role_id: str,
     instance_iam_role_id: str,
@@ -620,6 +659,7 @@ def register_cloud(  # noqa: PLR0913, PLR0912
     firewall_policy_names: str,
     cloud_storage_bucket_name: str,
     cloud_storage_bucket_endpoint: Optional[str],
+    cloud_storage_bucket_region: Optional[str],
     nfs_mount_target: List[str],
     nfs_mount_path: str,
     memorystore_instance_name: str,
@@ -634,28 +674,38 @@ def register_cloud(  # noqa: PLR0913, PLR0912
 ) -> None:
     missing_args: List[str] = []
     if provider == "aws":
+        if s3_bucket_id and not cloud_storage_bucket_name:
+            cloud_storage_bucket_name = s3_bucket_id
+        if efs_id and not file_storage_id:
+            file_storage_id = efs_id
         # Check for missing required arguments for AWS clouds,
         # based on the compute stack (not all args are required
         # on all compute stacks).
-        for resource in [
+        required_resources = [
             (vpc_id, "--vpc-id", (ComputeStack.VM)),
             (subnet_ids, "--subnet-ids", (ComputeStack.VM)),
-            (efs_id, "--efs-id", (ComputeStack.VM)),
-            (
-                anyscale_iam_role_id,
-                "--anyscale-iam-role-id",
-                (ComputeStack.VM, ComputeStack.K8S),
-            ),
+            (anyscale_iam_role_id, "--anyscale-iam-role-id", (ComputeStack.VM),),
             (instance_iam_role_id, "--instance-iam-role-id", (ComputeStack.VM)),
             (security_group_ids, "--security-group-ids", (ComputeStack.VM)),
-            (s3_bucket_id, "--s3-bucket-id", (ComputeStack.VM, ComputeStack.K8S)),
+            (
+                cloud_storage_bucket_name,
+                "--cloud-storage-bucket-name",
+                (ComputeStack.VM, ComputeStack.K8S),
+            ),
             (kubernetes_zones, "--kubernetes-zones", (ComputeStack.K8S)),
             (
                 anyscale_operator_iam_identity,
                 "--anyscale-operator-iam-identity",
                 (ComputeStack.K8S),
             ),
-        ]:
+        ]
+
+        if not allow_optional_file_storage():
+            required_resources.append(
+                (file_storage_id, "--file-storage-id", (ComputeStack.VM)),
+            )
+
+        for resource in required_resources:
             if compute_stack in resource[2] and resource[0] is None:
                 missing_args.append(resource[1])
 
@@ -668,13 +718,13 @@ def register_cloud(  # noqa: PLR0913, PLR0912
             name=name,
             vpc_id=vpc_id,
             subnet_ids=subnet_ids.split(",") if subnet_ids else [],
-            efs_id=efs_id,
+            efs_id=file_storage_id,
             anyscale_iam_role_id=anyscale_iam_role_id,
             instance_iam_role_id=instance_iam_role_id,
             security_group_ids=security_group_ids.split(",")
             if security_group_ids
             else [],
-            s3_bucket_id=s3_bucket_id,
+            cloud_storage_bucket_name=cloud_storage_bucket_name,
             memorydb_cluster_id=memorydb_cluster_id,
             functional_verify=functional_verify,
             kubernetes_zones=kubernetes_zones.split(",") if kubernetes_zones else [],
@@ -687,26 +737,26 @@ def register_cloud(  # noqa: PLR0913, PLR0912
             external_id=external_id,
         )
     elif provider == "gcp":
+        if filestore_instance_id and not file_storage_id:
+            file_storage_id = filestore_instance_id
         # Keep the parameter naming ({resource}_name or {resource}_id) consistent with GCP to reduce confusion for customers
         # Check if all required parameters are provided
         # memorystore_instance_name and host_project_id are optional for GCP clouds
-        for resource in [
-            (project_id, "--project-id", (ComputeStack.VM, ComputeStack.K8S)),
+        required_resources = [
+            (project_id, "--project-id", (ComputeStack.VM)),
             (vpc_name, "--vpc-name", (ComputeStack.VM)),
             (subnet_names, "--subnet-names", (ComputeStack.VM)),
-            (filestore_instance_id, "--filestore-instance-id", (ComputeStack.VM)),
-            (filestore_location, "--filestore-location", (ComputeStack.VM)),
             (
                 anyscale_service_account_email,
                 "--anyscale-service-account-email",
-                (ComputeStack.VM, ComputeStack.K8S),
+                (ComputeStack.VM),
             ),
             (
                 instance_service_account_email,
                 "--instance-service-account-email",
                 (ComputeStack.VM),
             ),
-            (provider_name, "--provider-name", (ComputeStack.VM, ComputeStack.K8S)),
+            (provider_name, "--provider-name", (ComputeStack.VM)),
             (firewall_policy_names, "--firewall-policy-names", (ComputeStack.VM)),
             (
                 cloud_storage_bucket_name,
@@ -719,21 +769,32 @@ def register_cloud(  # noqa: PLR0913, PLR0912
                 "--anyscale-operator-iam-identity",
                 (ComputeStack.K8S),
             ),
-        ]:
+        ]
+
+        if not allow_optional_file_storage():
+            required_resources.extend(
+                [
+                    (file_storage_id, "--file-storage-id", (ComputeStack.VM)),
+                    (filestore_location, "--filestore-location", (ComputeStack.VM)),
+                ]
+            )
+
+        for resource in required_resources:
             if compute_stack in resource[2] and resource[0] is None:
                 missing_args.append(resource[1])
 
         if len(missing_args) > 0:
             raise click.ClickException(f"Please provide a value for {missing_args}")
 
-        if project_id[0].isdigit():
+        if project_id and project_id[0].isdigit():
             # project ID should start with a letter
             raise click.ClickException(
                 "Please provide a valid project ID. Note that project ID is not project number, see https://cloud.google.com/resource-manager/docs/creating-managing-projects#before_you_begin for details."
             )
 
         if (
-            re.search(
+            compute_stack != ComputeStack.K8S
+            and re.search(
                 "projects/[0-9]*/locations/global/workloadIdentityPools/.+/providers/.+",
                 provider_name,
             )
@@ -766,7 +827,7 @@ def register_cloud(  # noqa: PLR0913, PLR0912
             project_id=project_id,
             vpc_name=vpc_name,
             subnet_names=subnet_names.split(",") if subnet_names else [],
-            filestore_instance_id=filestore_instance_id,
+            filestore_instance_id=file_storage_id,
             filestore_location=filestore_location,
             anyscale_service_account_email=anyscale_service_account_email,
             instance_service_account_email=instance_service_account_email,
@@ -803,6 +864,7 @@ def register_cloud(  # noqa: PLR0913, PLR0912
             region=region,
             cloud_storage_bucket_name=cloud_storage_bucket_name,
             cloud_storage_bucket_endpoint=cloud_storage_bucket_endpoint,
+            cloud_storage_bucket_region=cloud_storage_bucket_region,
             nfs_mount_targets=list(nfs_mount_target) if nfs_mount_target else [],
             nfs_mount_path=nfs_mount_path,
             kubernetes_zones=kubernetes_zones.split(",") if kubernetes_zones else [],
@@ -994,3 +1056,37 @@ def cloud_edit(  # noqa: PLR0913
         raise click.ClickException(
             "Please provide at least one of the following arguments: --aws-s3-id, --aws-efs-id, --aws-efs-mount-target-ip, --memorydb-cluster-id, --gcp-filestore-instance-id, --gcp-filestore-location, --gcp-cloud-storage-bucket-name, --memorystore-instance-name, --enable-auto-add-user, --disable-auto-add-user."
         )
+
+
+@cloud_cli.command(
+    name="add-collaborators",
+    help="Add collaborators to the cloud.",
+    cls=AnyscaleCommand,
+    example=command_examples.CLOUD_ADD_COLLABORATORS_EXAMPLE,
+)
+@click.option(
+    "--cloud", "-c", help="Name of the cloud to add collaborators to.", required=True
+)
+@click.option(
+    "--users-file",
+    help="Path to a YAML file containing a list of users to add to the cloud.",
+    required=True,
+)
+def add_collaborators(cloud: str, users_file: str,) -> None:
+    collaborators = CreateCloudCollaborators.from_yaml(users_file)
+
+    try:
+        anyscale.cloud.add_collaborators(
+            cloud=cloud,
+            collaborators=[
+                CreateCloudCollaborator(**collaborator)
+                for collaborator in collaborators.collaborators
+            ],
+        )
+    except ValueError as e:
+        log.error(f"Error adding collaborators to cloud: {e}")
+        return
+
+    log.info(
+        f"Successfully added {len(collaborators.collaborators)} collaborators to cloud {cloud}."
+    )
