@@ -3,6 +3,8 @@ from typing import Optional
 
 import click
 
+from anyscale.commands import workspace_commands_v2
+from anyscale.commands.util import LegacyAnyscaleCommand
 from anyscale.controllers.cluster_controller import ClusterController
 from anyscale.util import validate_non_negative_arg
 
@@ -16,7 +18,11 @@ def cluster_cli() -> None:
 
 
 @cluster_cli.command(
-    name="start", help="Start or update and restart a cluster on Anyscale."
+    name="start",
+    help="Start or update and restart a cluster on Anyscale.",
+    cls=LegacyAnyscaleCommand,
+    new_prefix="anyscale workspace_v2",
+    new_cli=workspace_commands_v2.start,
 )
 @click.option(
     "--name",
@@ -180,7 +186,13 @@ def start(  # noqa: PLR0913
     )
 
 
-@cluster_cli.command(name="terminate", help="Terminate a cluster on Anyscale.")
+@cluster_cli.command(
+    name="terminate",
+    help="Terminate a cluster on Anyscale.",
+    cls=LegacyAnyscaleCommand,
+    new_prefix="anyscale workspace_v2",
+    new_cli=workspace_commands_v2.terminate,
+)
 @click.option(
     "--name",
     "-n",
