@@ -186,11 +186,41 @@ sent 188 bytes  received 39 bytes  151.33 bytes/sec
 total size is 0  speedup is 0.00
 """
 
+WORKSPACE_UPDATE_EXAMPLE = """\
+$ anyscale workspace_v2 update expwrk_6l2ldwbu8299ympgltn725ciak --config-file config.yaml
+(anyscale +2.3s) Workspace updated successfully id: expwrk_6l2ldwbu8299ympgltn725ciak
+(anyscale +5.6s) Applied dynamic requirements to workspace id: expwrk_6l2ldwbu8299ympgltn725ciak
+(anyscale +9.1s) Applied environment variables to workspace id: expwrk_6l2ldwbu8299ympgltn725ciak
+
+$ cat config.yaml
+name: my-workspace
+idle_termination_minutes: 10
+env_vars:
+    HUMPDAY: WEDS
+requirements: requirements.txt
+"""
+
+WORKSPACE_GET_EXAMPLE = """\
+$ anyscale workspace_v2 get --name my-workspace
+id: my-workspace-id
+name: my-workspace
+state: RUNNING
+"""
+
 MACHINE_POOL_CREATE_EXAMPLE = """\
 $ anyscale machine-pool create --name can-testing
 Machine pool can-testing has been created successfully (ID mp_8ogdz85mdwxb8a92yo44nn84ox).
 """
 
+MACHINE_POOL_UPDATE_EXAMPLE = """\
+$ anyscale machine-pool update --name can-testing --spec-file spec.yaml
+Updated machine pool 'can-testing'.
+"""
+
+MACHINE_POOL_DESCRIBE_EXAMPLE = """\
+$ anyscale machine-pool describe --name can-testing --mode machines
+"""
+
 MACHINE_POOL_DELETE_EXAMPLE = """\
 $ anyscale machine-pool delete --name can-testing
 Deleted machine pool 'can-testing'.
@@ -459,3 +489,78 @@ IMAGE_REGISTER_EXAMPLE = """
 $ anyscale image register --image-uri docker.io/myrepo/image:v2 --name mycoolimage --ray-version 2.30.0
 Image registered successfully with URI: anyscale/image/mycoolimage:1
 """
+
+AGGREGATED_INSTANCE_USAGE_DOWNLOAD_CSV_EXAMPLE = """\
+$ anyscale aggregated-instance-usage download-csv --start-date 2024-10-01 --end-date 2024-10-03
+(anyscale +0.5s) Downloading aggregated instance usage CSV...
+Download complete! File saved to 'aggregated_instance_usage_2024-10-01_2024-10-03.zip'
+0:00:01 100% ━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━ 79.4 kB / 79.4 kB Downloading aggregated instance usage CSV
+(anyscale +2.2s) Downloaded CSV to aggregated_instance_usage_2024-10-01_2024-10-03.zip
+"""
+
+USER_BATCH_CREATE_EXAMPLE = """\
+$ anyscale user batch-create --users-file users.yaml
+(anyscale +0.5s) Creating users...
+(anyscale +0.8s) 2 users created.
+
+$ cat users_file.yaml
+create_users:
+  - name: name1
+    email: test1@anyscale.com
+    password: ''
+    is_sso_user: false
+    lastname: lastname1
+    title: title1
+  - name: name2
+    email: test2@anyscale.com
+    password: ''
+    is_sso_user: false
+    lastname: lastname2
+    title: title2
+"""
+
+ORGANIZATION_INVITATION_CREATE_EXAMPLE = """\
+$ anyscale organization-invitation create --emails test1@anyscale.com,test2@anyscale.com
+(anyscale +0.5s) Creating organization invitations...
+(anyscale +1.7s) Organization invitations sent to: test1@anyscale.com, test2@anyscale.com
+"""
+
+ORGANIZATION_INVITATION_LIST_EXAMPLE = """\
+$ anyscale organization-invitation list
+ID             Email              Created At           Expires At
+-------------  -----------------  -------------------  -------------------
+orginv_abcedf  test@anyscale.com  11/25/2024 10:24 PM  12/02/2024 10:24 PM
+"""
+
+ORGANIZATION_INVITATION_DELETE_EXAMPLE = """\
+$ anyscale organization-invitation delete --email test@anyscale.com
+(anyscale +0.6s) Organization invitation for test@anyscale.com deleted.
+"""
+
+PROJECT_ADD_COLLABORATORS_EXAMPLE = """\
+$ anyscale project add-collaborators --cloud cloud_name --project project_name --users-file collaborators.yaml
+(anyscale +1.3s) Successfully added 3 collaborators to project project_name.
+$ cat collaborators.yaml
+collaborators:
+  - email: "test1@anyscale.com"
+    permission_level: "write"
+  - email: "test2@anyscale.com"
+    permission_level: "readonly"
+  - email: "test3@anyscale.com"
+    permission_level: "owner"
+"""
+
+CLOUD_ADD_COLLABORATORS_EXAMPLE = """\
+$ anyscale cloud add-collaborators --cloud cloud_name --users-file collaborators.yaml
+(anyscale +1.3s) Successfully added 2 collaborators to cloud cloud_name.
+$ cat collaborators.yaml
+collaborators:
+  - email: "test1@anyscale.com"
+    permission_level: "write"
+  - email: "test2@anyscale.com"
+    permission_level: "readonly"
+"""
+
+SERVICE_ARCHIVE_EXAMPLE = """\
+$ anyscale service archive --name my_service
+"""
