@@ -2,7 +2,7 @@ from io import StringIO
 from json import dumps as json_dumps
 import pathlib
 from subprocess import list2cmdline
-from typing import Optional, Tuple
+from typing import List, Optional, Tuple
 
 import click
 import yaml
@@ -10,6 +10,7 @@ import yaml
 import anyscale
 from anyscale._private.models.image_uri import ImageURI
 from anyscale.cli_logger import BlockLogger
+from anyscale.client.openapi_client.models.ha_job_states import HaJobStates
 from anyscale.commands import command_examples
 from anyscale.commands.util import (
     AnyscaleCommand,
@@ -18,7 +19,7 @@ from anyscale.commands.util import (
 )
 from anyscale.controllers.job_controller import JobController
 from anyscale.job.models import JobConfig, JobLogMode, JobState, JobStatus
-from anyscale.util import validate_non_negative_arg
+from anyscale.util import validate_list_jobs_state_filter, validate_non_negative_arg
 
 
 log = BlockLogger()  # CLI Logger
@@ -118,7 +119,7 @@ def job_cli() -> None:
     required=False,
     default=None,
     type=str,
-    help="Path to a requirements.txt file containing dependencies for the job. These will be installed on top of the image. When running in a workspace, this defaults to the workspace dependencies.",
+    help="Path to a requirements.txt file containing dependencies for the job. Anyscale installs these dependencies on top of the image. If you run a job from a workspace, the default is to use the workspace dependencies, but specifying this option overrides them.",
 )
 @click.option(
     "--py-module",
@@ -386,6 +387,15 @@ and override the entrypoint with `python main.py`.
     help="Max items to show in list.",
     callback=validate_non_negative_arg,
 )
+@click.option(
+    "--state",
+    "-s",
+    "states",
+    required=False,
+    multiple=True,
+    help=f"Filter jobs by state. Accepts one or more states. Allowed states: {', '.join(HaJobStates.allowable_values)}",
+    callback=validate_list_jobs_state_filter,
+)
 def list(  # noqa: A001
     name: Optional[str],
     id: Optional[str],  # noqa: A002
@@ -393,6 +403,7 @@ def list(  # noqa: A001
     include_all_users: bool,
     include_archived: bool,
     max_items: int,
+    states: List[str],
 ) -> None:
     job_controller = JobController()
     job_controller.list(
@@ -402,6 +413,7 @@ def list(  # noqa: A001
         include_all_users=include_all_users,
         include_archived=include_archived,
         max_items=max_items,
+        states=states,
     )
 
 
