@@ -2,10 +2,16 @@ from typing import Optional
 
 import click
 
+import anyscale
 from anyscale.cli_logger import BlockLogger
-from anyscale.commands.util import LegacyAnyscaleCommand, NotRequiredIf
+from anyscale.commands import command_examples
+from anyscale.commands.util import AnyscaleCommand, LegacyAnyscaleCommand, NotRequiredIf
 from anyscale.controllers.project_controller import ProjectController
-from anyscale.project import validate_project_name
+from anyscale.project.models import (
+    CreateProjectCollaborator,
+    CreateProjectCollaborators,
+)
+from anyscale.project_utils import validate_project_name
 from anyscale.util import validate_non_negative_arg
 
 
@@ -201,3 +207,47 @@ def init(project_id: Optional[str], name: Optional[str],) -> None:
 def create(name: str, parent_cloud_id: str) -> None:
     project_controller = ProjectController()
     project_controller.create(name, parent_cloud_id)
+
+
+@project_cli.command(
+    name="add-collaborators",
+    help="Add collaborators to the project.",
+    cls=AnyscaleCommand,
+    example=command_examples.PROJECT_ADD_COLLABORATORS_EXAMPLE,
+)
+@click.option(
+    "--cloud",
+    "-c",
+    help="Name of the cloud that the project belongs to.",
+    required=True,
+)
+@click.option(
+    "--project",
+    "-p",
+    help="Name of the project to add collaborators to.",
+    required=True,
+)
+@click.option(
+    "--users-file",
+    help="Path to a YAML file containing a list of users to add to the project.",
+    required=True,
+)
+def add_collaborators(cloud: str, project: str, users_file: str,) -> None:
+    collaborators = CreateProjectCollaborators.from_yaml(users_file)
+
+    try:
+        anyscale.project.add_collaborators(
+            cloud=cloud,
+            project=project,
+            collaborators=[
+                CreateProjectCollaborator(**collaborator)
+                for collaborator in collaborators.collaborators
+            ],
+        )
+    except ValueError as e:
+        log.error(f"Error adding collaborators to project: {e}")
+        return
+
+    log.info(
+        f"Successfully added {len(collaborators.collaborators)} collaborators to project {project}."
+    )
