@@ -9,7 +9,9 @@ import yaml
 
 from anyscale._private.models.image_uri import ImageURI
 from anyscale.cli_logger import BlockLogger
+from anyscale.commands import command_examples
 from anyscale.commands.util import (
+    AnyscaleCommand,
     convert_kv_strings_to_dict,
     LegacyAnyscaleCommand,
     override_env_vars,
@@ -125,7 +127,7 @@ def _read_name_from_config_file(path: str):
     required=False,
     default=None,
     type=str,
-    help="Path to a requirements.txt file containing dependencies for the service. These will be installed on top of the image. When running in a workspace, this defaults to the workspace dependencies.",
+    help="Path to a requirements.txt file containing dependencies for the service. Anyscale installs these dependencies on top of the image. If you deploy a service from a workspace, the default is to use the workspace dependencies, but specifying this option overrides them.",
 )
 @click.option(
     "-i",
@@ -736,3 +738,61 @@ def terminate(
         project_id=project_id,
     )
     service_controller.terminate(service_id)
+
+
+@service_cli.command(
+    name="archive",
+    help="Archive a service.",
+    cls=AnyscaleCommand,
+    example=command_examples.SERVICE_ARCHIVE_EXAMPLE,
+)
+@click.option(
+    "-n", "--name", required=False, default=None, type=str, help="Name of the service.",
+)
+@click.option(
+    "-f",
+    "--config-file",
+    required=False,
+    default=None,
+    type=str,
+    help="Path to a YAML config file to read the name from.",
+)
+@click.option(
+    "--cloud",
+    required=False,
+    default=None,
+    type=str,
+    help="The Anyscale Cloud to run this workload on. If not provided, the organization default will be used (or, if running in a workspace, the cloud of the workspace).",
+)
+@click.option(
+    "--project",
+    required=False,
+    default=None,
+    type=str,
+    help="Named project to use for the service. If not provided, the default project for the cloud will be used (or, if running in a workspace, the project of the workspace).",
+)
+def archive(
+    name: Optional[str],
+    config_file: Optional[str],
+    cloud: Optional[str],
+    project: Optional[str],
+) -> None:
+    """Archive a service.
+
+    To specify the service by name, use the --name flag. To specify the service by id, use the --id flag. Either name or
+id should be used, specifying both will result in an error.
+    """
+    if name is not None and config_file is not None:
+        raise click.ClickException(
+            "Only one of '--name' and '--config-file' can be provided."
+        )
+
+    if config_file is not None:
+        name = _read_name_from_config_file(config_file)
+
+    if name is None:
+        raise click.ClickException(
+            "Service name must be provided using '--name' or in a config file using '-f'."
+        )
+
+    anyscale.service.archive(name=name, cloud=cloud, project=project)
