@@ -125,8 +125,8 @@ def convert_kv_strings_to_dict(strings: Tuple[str]) -> Dict[str, str]:
     """
     ret_dict = {}
     for s in strings:
-        split = s.split("=")
-        if len(split) != 2:
+        split = s.split("=", maxsplit=1)
+        if len(split) != 2 or len(split[1]) == 0:
             raise click.ClickException(
                 f"Invalid key-value string '{s}'. Must be of the form 'key=value'."
             )
