@@ -15,7 +15,7 @@ from anyscale.commands import workspace_commands_v2
 from anyscale.commands.util import LegacyAnyscaleCommand
 from anyscale.controllers.cluster_controller import ClusterController
 from anyscale.controllers.workspace_controller import WorkspaceController
-from anyscale.project import find_project_root
+from anyscale.project_utils import find_project_root
 from anyscale.shared_anyscale_utils.utils.byod import BYODInfo
 from anyscale.util import get_endpoint
 from anyscale.workspace_utils import (
@@ -186,7 +186,10 @@ def terminate(name: str) -> None:
 @click.option(
     "--name", "-n", required=True, help="Name of existing workspace to clone.",
 )
-def clone(name: str) -> None:
+@click.option(
+    "--verbose", "-v", required=False, is_flag=True, default=False, help="Verbose mode"
+)
+def clone(name: str, verbose: bool) -> None:
     """
     Clone the workspace to a local dir whose name is the name of the workspace.
     """
@@ -201,7 +204,7 @@ def clone(name: str) -> None:
         )
     workspace_controller.clone(workspace)
     os.chdir(dest)
-    _do_pull(pull_git_state=True)
+    _do_pull(pull_git_state=True, verbose=verbose)
 
 
 @workspace_cli.command(name="activate")
@@ -390,7 +393,7 @@ def copy_command(remote_path, local_path) -> None:
     _do_copy(remote_path, local_path)
 
 
-def _do_pull(pull_git_state):
+def _do_pull(pull_git_state, verbose=False):
     workspace_controller = WorkspaceController()
     dir_name = workspace_controller.get_workspace_dir_name()
     # Since workspaces store git objects in an EFS alternates dir, we have to force
@@ -409,6 +412,7 @@ def _do_pull(pull_git_state):
         rsync_excludes=[".anyscale.yaml", ".git/objects/info/alternates"]
         + ([] if pull_git_state else [".git"]),
         delete_existing_files_in_destination=True,
+        verbose=verbose,
     )
 
 
