@@ -543,8 +543,15 @@ id should be used, specifying both will result in an error.
     is_flag=True,
     help="Pull the git state of the workspace.",
 )
+@click.option(
+    "--delete",
+    required=False,
+    default=False,
+    is_flag=True,
+    help="Delete files in the local directory that are not in the workspace.",
+)
 @click.pass_context
-def pull(
+def pull(  # noqa: PLR0913
     ctx,
     id: Optional[str],  # noqa: A002
     name: Optional[str],
@@ -552,8 +559,9 @@ def pull(
     project: Optional[str],
     local_dir: Optional[str],
     pull_git_state: bool = False,
+    delete: bool = False,
 ) -> None:
-    """Pull the working directory of a workspace.
+    """Pull the working directory of a workspace. New files will be created, existing files will be overwritten.
 
     To specify the workspace by name, use the --name flag. To specify the workspace by id, use the --id flag. Either name or
 id should be used, specifying both will result in an error.
@@ -572,6 +580,7 @@ id should be used, specifying both will result in an error.
         local_dir=local_dir,
         pull_git_state=pull_git_state,
         rsync_args=ctx.args,
+        delete=delete,
     )
 
 
@@ -614,8 +623,15 @@ id should be used, specifying both will result in an error.
     is_flag=True,
     help="Push the git state of the workspace.",
 )
+@click.option(
+    "--delete",
+    required=False,
+    default=False,
+    is_flag=True,
+    help="Delete files in the workspace that are not in the local directory.",
+)
 @click.pass_context
-def push(
+def push(  # noqa: PLR0913
     ctx,
     id: Optional[str],  # noqa: A002
     name: Optional[str],
@@ -623,8 +639,9 @@ def push(
     project: Optional[str],
     local_dir: Optional[str],
     push_git_state: bool = False,
+    delete: bool = False,
 ) -> None:
-    """Push a local directory to a workspace.
+    """Push a local directory to a workspace. New files will be created, existing files will be overwritten.
 
     To specify the workspace by name, use the --name flag. To specify the workspace by id, use the --id flag. Either name or
 id should be used, specifying both will result in an error.
@@ -643,11 +660,15 @@ id should be used, specifying both will result in an error.
         local_dir=local_dir,
         push_git_state=push_git_state,
         rsync_args=ctx.args,
+        delete=delete,
     )
 
 
 @workspace_cli.command(
-    name="update", help="Update an existing workspace on Anyscale.",
+    name="update",
+    help="Update an existing workspace on Anyscale.",
+    cls=AnyscaleCommand,
+    example=command_examples.WORKSPACE_UPDATE_EXAMPLE,
 )
 @click.argument("workspace-id", type=str)
 @click.option(
@@ -791,7 +812,10 @@ def update(  # noqa: PLR0913, PLR0912
 
 
 @workspace_cli.command(
-    name="get", short_help="Get a workspace.", cls=AnyscaleCommand,
+    name="get",
+    short_help="Get a workspace.",
+    cls=AnyscaleCommand,
+    example=command_examples.WORKSPACE_GET_EXAMPLE,
 )
 @click.option(
     "--id", "--workspace-id", required=False, help="Unique ID of the workspace."
