@@ -42,14 +42,14 @@ class PrivateComputeConfigSDK(BaseSDK):
         if not config.advanced_instance_config:
             return
 
+        # Always pass the advanced configuration through `advanced_configurations_json`.
+        # After fully migrated, we can stop setting the cloud-specific advanced configurations here.
+        api_model.advanced_configurations_json = config.advanced_instance_config
+
         if cloud.provider == CloudProviders.AWS:
             api_model.aws_advanced_configurations_json = config.advanced_instance_config
         elif cloud.provider == CloudProviders.GCP:
             api_model.gcp_advanced_configurations_json = config.advanced_instance_config
-        else:
-            raise ValueError(
-                f"'advanced_instance_config' is not implemented for cloud provider: '{cloud.provider}'"
-            )
 
     def _convert_resource_dict_to_api_model(
         self, resource_dict: Optional[Dict[str, float]]
@@ -223,6 +223,9 @@ class PrivateComputeConfigSDK(BaseSDK):
         *,
         cloud: Cloud,
     ) -> Optional[Dict]:
+        if api_model.advanced_configurations_json:
+            return api_model.advanced_configurations_json
+
         if cloud.provider == CloudProviders.AWS:
             return api_model.aws_advanced_configurations_json or None
         elif cloud.provider == CloudProviders.GCP:
