@@ -610,10 +610,9 @@ class PrepareClusterBlock:
         not provided, use the latest revision.
         """
         app_template_id = None
-        cluster_environments = list_entities(
-            self.anyscale_api_client.list_app_configs,
-            filters={"name_contains": cluster_env_name},
-        )
+        cluster_environments = self.anyscale_api_client.search_cluster_environments(
+            {"name": {"equals": cluster_env_name},}
+        ).results
         for cluster_env in cluster_environments:
             if cluster_env.name == cluster_env_name:
                 app_template_id = cluster_env.id
@@ -622,7 +621,9 @@ class PrepareClusterBlock:
                 f"Cluster Environment '{cluster_env_name}' not found. See environments at "
                 f'{get_endpoint("/configurations/?tab=cluster-env")}.'
             )
-        builds = list_entities(self.anyscale_api_client.list_builds, app_template_id)
+        builds = list_entities(
+            self.anyscale_api_client.list_cluster_environment_builds, app_template_id
+        )
 
         build_to_use = None
         if clust_env_revision:
@@ -680,7 +681,7 @@ class PrepareClusterBlock:
                 "the provided cluster environment dictionary.",
                 block_label=self.block_label,
             )
-            self.anyscale_api_client.create_app_config(
+            self.anyscale_api_client.create_cluster_environment(
                 {
                     "name": cluster_env_name,
                     "project_id": project_id,
@@ -707,11 +708,11 @@ class PrepareClusterBlock:
         # Force creation of a unique app config.
         if force_rebuild:
             config_name += f"-{int(time.time())}"
-        app_templates = list_entities(
-            self.anyscale_api_client.list_app_configs,
-            filters={"name_contains": config_name},
+        cluster_environments = list_entities(
+            self.anyscale_api_client.search_cluster_environments,
+            filters={"name": {"equals": config_name}},
         )
-        found = any(a.name == config_name for a in app_templates)
+        found = any(a.name == config_name for a in cluster_environments)
         if not found:
             build_steps = BUILD_STEPS.copy()
             # Add a unique command to bust the Makisu cache if needed.
@@ -727,7 +728,7 @@ class PrepareClusterBlock:
             build_steps.append(
                 'cd ray/python && sudo env "PATH=$PATH" python setup.py develop'
             )
-            self.anyscale_api_client.create_app_config(
+            self.anyscale_api_client.create_cluster_environment(
                 {
                     "name": config_name,
                     "project_id": project_id,
@@ -855,7 +856,7 @@ class PrepareClusterBlock:
                 current_cluster_build = self.anyscale_api_client.get_build(
                     running_cluster.build_id
                 ).result
-                current_cluster_env = self.anyscale_api_client.get_app_config(
+                current_cluster_env = self.anyscale_api_client.get_cluster_environment(
                     current_cluster_build.application_template_id
                 ).result
                 if print_warnings:
