@@ -27,7 +27,7 @@ class AuthController:
         log_output: bool = True,
     ):
         self.log = LogsLogger(log_output=log_output)
-        self.url = get_endpoint("/credentials")
+        self.url = get_endpoint("/v2/api-keys")
         self.path = os.path.expanduser(path)
         if warn_envvar:
             self._warn_environment_variable()
