@@ -30,7 +30,7 @@ from anyscale.client.openapi_client.models import (
     SessionState,
 )
 from anyscale.controllers.base_controller import BaseController
-from anyscale.project import get_default_project
+from anyscale.project_utils import get_default_project
 from anyscale.sdk.anyscale_client.models import (
     ComputeNodeType,
     ComputeTemplateQuery,
