@@ -7,7 +7,7 @@ import tabulate
 import yaml
 
 from anyscale.cli_logger import BlockLogger
-from anyscale.cloud import get_cloud_id_and_name, get_last_used_cloud
+from anyscale.cloud_utils import get_cloud_id_and_name, get_last_used_cloud
 from anyscale.cluster_compute import (
     get_cluster_compute_from_name,
     get_default_cluster_compute,
@@ -18,7 +18,7 @@ from anyscale.cluster_env import (
     get_default_cluster_env_build,
 )
 from anyscale.controllers.base_controller import BaseController
-from anyscale.project import (
+from anyscale.project_utils import (
     get_and_validate_project_id,
     get_proj_id_from_name,
     get_project_id,
@@ -411,7 +411,6 @@ class ClusterController(BaseController):
                 cluster.id,
                 cluster.state,
                 cluster.cloud_id,
-                cluster.cost_since_restarted_dollars,
                 get_endpoint(f"/projects/{cluster.project_id}/clusters/{cluster.id}"),
             ]
             for cluster in cluster_list
@@ -419,14 +418,7 @@ class ClusterController(BaseController):
 
         table = tabulate.tabulate(
             clusters_table,
-            headers=[
-                "NAME",
-                "ID",
-                "STATE",
-                "CLOUD ID",
-                "COST SINCE LAST START",
-                "URL",
-            ],
+            headers=["NAME", "ID", "STATE", "CLOUD ID", "URL",],
             tablefmt="plain",
         )
         print(f"Clusters:\n{table}")
