@@ -29,7 +29,7 @@ from anyscale.client.openapi_client.models.decorated_production_job import (
 from anyscale.client.openapi_client.models.ha_job_states import HaJobStates
 from anyscale.controllers.base_controller import BaseController
 from anyscale.models.job_model import JobConfig
-from anyscale.project import infer_project_id
+from anyscale.project_utils import infer_project_id
 from anyscale.sdk.anyscale_client.models.job import Job
 from anyscale.sdk.anyscale_client.models.jobs_query import JobsQuery
 from anyscale.sdk.anyscale_client.models.jobs_sort_field import JobsSortField
@@ -65,6 +65,8 @@ _PENDING_STATES = {
     HaJobStates.RESTARTING,
 }
 
+DEFAULT_PAGE_LIMIT = 500
+
 
 class MiniJobRun(BaseModel):
     last_job_run_id: str
@@ -292,6 +294,7 @@ class JobController(BaseController):
         project_id: Optional[str],
         include_archived: bool,
         max_items: int,
+        states: List[str],
     ) -> None:
         """
         This function will list jobs.
@@ -313,7 +316,6 @@ class JobController(BaseController):
             output_map = {
                 "Name": job.name,
                 "Id": job.id,
-                "Cost (dollars)": job.cost_dollars,
                 "Project name": job.project.name,
                 "Cluster name": job.last_job_run.cluster.name
                 if job.last_job_run and job.last_job_run.cluster
@@ -342,7 +344,8 @@ class JobController(BaseController):
                 creator_id=creator_id,
                 type_filter="BATCH_JOB",
                 archive_status="ALL" if include_archived else "NOT_ARCHIVED",
-                count=10,
+                count=DEFAULT_PAGE_LIMIT,
+                state_filter=states,
             )
             jobs_list.extend(resp.results)
             paging_token = resp.metadata.next_paging_token
@@ -354,8 +357,9 @@ class JobController(BaseController):
                     creator_id=creator_id,
                     type_filter="BATCH_JOB",
                     archive_status="ALL" if include_archived else "NOT_ARCHIVED",
-                    count=10,
+                    count=DEFAULT_PAGE_LIMIT,
                     paging_token=paging_token,
+                    state_filter=states,
                 )
                 jobs_list.extend(resp.results)
                 paging_token = resp.metadata.next_paging_token
@@ -366,7 +370,6 @@ class JobController(BaseController):
             [
                 job.name,
                 job.id,
-                job.cost_dollars,
                 job.project.name,
                 job.last_job_run.cluster.name
                 if job.last_job_run and job.last_job_run.cluster
@@ -385,7 +388,6 @@ class JobController(BaseController):
             headers=[
                 "NAME",
                 "ID",
-                "COST",
                 "PROJECT NAME",
                 "CLUSTER NAME",
                 "CURRENT STATE",
