@@ -1,6 +1,8 @@
+import pathlib
 from typing import Optional
 
 from rich.console import Console
+import yaml
 
 from anyscale.cli_logger import BlockLogger
 from anyscale.client.openapi_client.models import (
@@ -8,10 +10,13 @@ from anyscale.client.openapi_client.models import (
     CreateMachinePoolRequest,
     CreateMachinePoolResponse,
     DeleteMachinePoolRequest,
+    DescribeMachinePoolRequest,
+    DescribeMachinePoolResponse,
     DetachMachinePoolFromCloudRequest,
     ListMachinePoolsResponse,
+    UpdateMachinePoolRequest,
 )
-from anyscale.cloud import get_cloud_id_and_name
+from anyscale.cloud_utils import get_cloud_id_and_name
 from anyscale.controllers.base_controller import BaseController
 
 
@@ -46,6 +51,31 @@ class MachinePoolController(BaseController):
             DeleteMachinePoolRequest(machine_pool_name=machine_pool_name)
         )
 
+    def update_machine_pool(
+        self, machine_pool_name: str, spec_file: str,
+    ):
+        path = pathlib.Path(spec_file)
+        if not path.exists():
+            raise FileNotFoundError(f"File {spec_file} does not exist.")
+
+        if not path.is_file():
+            raise ValueError(f"File {spec_file} is not a file.")
+
+        spec = yaml.safe_load(path.read_text())
+
+        self.api_client.update_machine_pool_api_v2_machine_pools_update_post(
+            UpdateMachinePoolRequest(machine_pool_name=machine_pool_name, spec=spec,)
+        )
+
+    def describe_machine_pool(
+        self, machine_pool_name: str,
+    ) -> DescribeMachinePoolResponse:
+        return self.api_client.describe_machine_pool_api_v2_machine_pools_describe_post(
+            describe_machine_pool_request=DescribeMachinePoolRequest(
+                machine_pool_name=machine_pool_name,
+            )
+        ).result
+
     def list_machine_pools(self,) -> ListMachinePoolsResponse:
         response = self.api_client.list_machine_pools_api_v2_machine_pools_get().result
         return response
