@@ -19,7 +19,7 @@ from anyscale.client.openapi_client.models.decorated_production_service_v2_api_m
 )
 from anyscale.controllers.base_controller import BaseController
 from anyscale.models.service_model import ServiceConfig
-from anyscale.project import infer_project_id
+from anyscale.project_utils import infer_project_id
 from anyscale.sdk.anyscale_client.models import (
     ApplyServiceModel,
     RollbackServiceModel,
