@@ -6,6 +6,9 @@ from typing import Any
 import click
 
 from anyscale.cli_logger import BlockLogger
+from anyscale.commands.aggregated_instance_usage_commands import (
+    aggregated_instance_usage_cli,
+)
 from anyscale.commands.anyscale_api.api_commands import anyscale_api
 from anyscale.commands.auth_commands import auth_cli
 from anyscale.commands.cloud_commands import cloud_cli
@@ -26,12 +29,16 @@ from anyscale.commands.logs_commands import log_cli
 from anyscale.commands.machine_commands import machine_cli
 from anyscale.commands.machine_pool_commands import machine_pool_cli
 from anyscale.commands.migrate_commands import migrate_cli
+from anyscale.commands.organization_invitation_commands import (
+    organization_invitation_cli,
+)
 from anyscale.commands.project_commands import anyscale_init, project_cli
 from anyscale.commands.resource_quota_commands import resource_quota_cli
 from anyscale.commands.schedule_commands import schedule_cli
 from anyscale.commands.service_account_commands import service_account_cli
 from anyscale.commands.service_commands import service_cli
 from anyscale.commands.session_commands_hidden import session_cli
+from anyscale.commands.user_commands import user_cli
 from anyscale.commands.workspace_commands import workspace_cli
 from anyscale.commands.workspace_commands_v2 import workspace_cli as workspace_cli_v2
 import anyscale.conf
@@ -138,6 +145,9 @@ cli.add_command(machine_cli)
 cli.add_command(machine_pool_cli)
 cli.add_command(service_account_cli)
 cli.add_command(resource_quota_cli)
+cli.add_command(aggregated_instance_usage_cli)
+cli.add_command(user_cli)
+cli.add_command(organization_invitation_cli)
 
 ALIASES = {
     "h": anyscale_help,
