@@ -39,7 +39,7 @@ from anyscale.util import get_endpoint
 from anyscale.authenticate import AuthenticationBlock
 from anyscale_client.models import ClusterEnvironmentBuildStatus
 from anyscale.util import get_ray_and_py_version_for_default_cluster_env
-from anyscale.project import get_default_project
+from anyscale.project_utils import get_default_project
 from anyscale.utils.ray_version_utils import get_correct_name_for_base_image_name
 
 logger = logging.getLogger(__file__)
