@@ -6,6 +6,8 @@ from anyscale._private.sdk.base_sdk import Timer
 from anyscale.cli_logger import BlockLogger
 from anyscale.service._private.service_sdk import PrivateServiceSDK
 from anyscale.service.commands import (
+    _ARCHIVE_ARG_DOCSTRINGS,
+    _ARCHIVE_EXAMPLE,
     _controller_logs,
     _CONTROLLER_LOGS_ARG_DOCSTRINGS,
     _CONTROLLER_LOGS_EXAMPLE,
@@ -19,6 +21,7 @@ from anyscale.service.commands import (
     _TERMINATE_EXAMPLE,
     _WAIT_ARG_DOCSTRINGS,
     _WAIT_EXAMPLE,
+    archive,
     deploy,
     rollback,
     status,
@@ -111,6 +114,24 @@ class ServiceSDK:
         """
         return self._private_sdk.terminate(name=name, cloud=cloud, project=project)
 
+    @sdk_docs(
+        doc_py_example=_ARCHIVE_EXAMPLE, arg_docstrings=_ARCHIVE_ARG_DOCSTRINGS,
+    )
+    def archive(  # noqa: F811
+        self,
+        name: Optional[str] = None,
+        *,
+        cloud: Optional[str] = None,
+        project: Optional[str] = None,
+    ) -> str:
+        """Archive a service.
+
+        This command is asynchronous, so it always returns immediately.
+
+        Returns the ID of the archived service.
+        """
+        return self._private_sdk.archive(name=name, cloud=cloud, project=project)
+
     @sdk_docs(
         doc_py_example=_STATUS_EXAMPLE, arg_docstrings=_STATUS_ARG_DOCSTRINGS,
     )
