@@ -493,6 +493,19 @@ class PrivateServiceSDK(WorkloadSDK):
 
         return model.id
 
+    def archive(
+        self,
+        name: Optional[str] = None,
+        *,
+        cloud: Optional[str] = None,
+        project: Optional[str] = None,
+    ) -> str:
+        model = self._resolve_to_service_model(name=name, cloud=cloud, project=project)
+
+        self.client.archive_service(model.id)
+
+        return model.id
+
     def _get_user_facing_service_version_id(
         self, model: ProductionServiceV2VersionModel
     ) -> str:
