@@ -657,3 +657,15 @@ primary_version:
             )
 
         return canary_version
+
+
+class ServiceLogMode(ModelEnum):
+    """Mode to use for getting job logs."""
+
+    HEAD = "HEAD"
+    TAIL = "TAIL"
+
+    __docstrings__ = {
+        HEAD: "Fetch logs from the start.",
+        TAIL: "Fetch logs from the end.",
+    }
