@@ -44,6 +44,7 @@ from anyscale.client.openapi_client.models.cloud_analytics_event_cloud_resource
 from anyscale.client.openapi_client.models.decorated_compute_template import (
     DecoratedComputeTemplate,
 )
+from anyscale.client.openapi_client.models.ha_job_states import HaJobStates
 from anyscale.client.openapi_client.models.user_info import UserInfo
 from anyscale.cluster_compute import get_cluster_compute_from_name
 import anyscale.conf
@@ -986,6 +987,20 @@ def validate_job_config_dict(
         )
 
 
+def validate_list_jobs_state_filter(ctx, param, value) -> List[str]:  # noqa: ARG001
+    """
+    Validate the job state filter for list jobs CLI method
+    """
+    if not value:
+        return []
+    for each_value in value:
+        if each_value.upper() not in HaJobStates.allowable_values:
+            raise click.ClickException(
+                f"{each_value} is not a valid value for {param.opts[0]}. Allowed values: {', '.join(HaJobStates.allowable_values)}"
+            )
+    return [each_value.upper() for each_value in value]
+
+
 def get_cluster_model_for_current_workspace(
     anyscale_api_client: BaseApi,
 ) -> Optional[Cluster]:
@@ -1153,3 +1168,11 @@ T = TypeVar("T")
 
 def _coerce_to_list(maybe_list: Union[T, List[T]]) -> List[T]:
     return maybe_list if isinstance(maybe_list, list) else [maybe_list]
+
+
+def allow_optional_file_storage(api_client: Optional[ProductApi] = None) -> bool:
+    if api_client is None:
+        api_client = get_auth_api_client().api_client
+    return api_client.check_is_feature_flag_on_api_v2_userinfo_check_is_feature_flag_on_get(
+        "allow-optional-file-storage"
+    ).result.is_on
