@@ -2,9 +2,10 @@ from enum import Enum
 from typing import Optional, Union
 
 import click
-from pydantic import BaseModel
 from typing_extensions import Literal
 
+from anyscale.anyscale_pydantic import BaseModel
+
 
 class EntityType(str, Enum):
     ID = "ID"
