@@ -59,16 +59,15 @@ def configure_bash_preexec():
     """
     Stores the bash-preexec support which will allow us to parse commands and submit them to anyscale backend.
     """
-    dir = pathlib.Path(__file__).parent.resolve()
+    dir = pathlib.Path(__file__).parent.resolve()  # noqa: A001
     shutil.copyfile(os.path.join(dir, "bash-preexec.sh"), BASH_PREEXEC)
 
-    bashrc_file_config = open(BASH_PREEXEC_CONFIG, "w")
-    bashrc_file_config.write(bashrc_preexec_content)
-    bashrc_file_config.close()
+    with open(BASH_PREEXEC_CONFIG, "w") as f:
+        f.write(bashrc_preexec_content)
 
 
 class Command:
-    def __init__(
+    def __init__(  # noqa: PLR0913
         self,
         term_name: str,
         scid: str = "",
