@@ -203,6 +203,7 @@ class WorkspaceSDK:
         local_dir: Optional[str] = None,
         pull_git_state: bool = False,
         rsync_args: Optional[List[str]] = None,
+        delete: bool = False,
     ):
         """Pull a file from a workspace."""
         self._private_sdk.pull(
@@ -213,6 +214,7 @@ class WorkspaceSDK:
             local_dir=local_dir,
             pull_git_state=pull_git_state,
             rsync_args=rsync_args,
+            delete=delete,
         )
 
     @sdk_docs(
@@ -228,6 +230,7 @@ class WorkspaceSDK:
         local_dir: Optional[str] = None,
         push_git_state: bool = False,
         rsync_args: Optional[List[str]] = None,
+        delete: bool = False,
     ):
         """Push a directory to a workspace."""
         self._private_sdk.push(
@@ -238,6 +241,7 @@ class WorkspaceSDK:
             local_dir=local_dir,
             push_git_state=push_git_state,
             rsync_args=rsync_args,
+            delete=delete,
         )
 
     @sdk_docs(
