@@ -4,6 +4,8 @@ import subprocess
 import tempfile
 from typing import cast, Dict, List, Optional, Tuple, Union
 
+import click
+
 from anyscale._private.workload.workload_sdk import WorkloadSDK
 from anyscale.client.openapi_client.models import (
     CreateExperimentalWorkspace,
@@ -28,7 +30,9 @@ Host Head-Node
   User ubuntu
   IdentityFile {key_path}
   StrictHostKeyChecking false
+  UserKnownHostsFile /dev/null
   IdentitiesOnly yes
+  LogLevel ERROR
 
 Host {name}
   HostName 0.0.0.0
@@ -37,9 +41,13 @@ Host {name}
   User ray
   IdentityFile {key_path}
   StrictHostKeyChecking false
+  UserKnownHostsFile /dev/null
   IdentitiesOnly yes
+  LogLevel ERROR
 """
 
+# TODO(bryce): These options are already stated in the SSH_TEMPLATE, but we
+# still pass them in the ssh command. It should be safe to remove them.
 ANYSCALE_WORKSPACES_SSH_OPTIONS = [
     "-o",
     "StrictHostKeyChecking=no",
@@ -371,6 +379,65 @@ class PrivateWorkspaceSDK(WorkloadSDK):
         )
         return self.client.get_workspace_default_dir_name(workspace_model.id)
 
+    def _parse_rsync_dry_run_output(
+        self, dry_run_output: str
+    ) -> Tuple[List[str], List[str]]:
+        """Parse rsync dry-run output to detect file changes vs additions.
+        Note that --itemize-changes is needed to detect file changes.
+        Format is like "<fcsT...... test.py" where:
+        - First char indicates operations (>, <, *)
+        - Third char (c or .) indicates if checksum changed (only if --checksum is used)
+
+        Returns:
+            Tuple of (modifying_files, deleting_files)
+        """
+        modifying_files = []
+        deleting_files = []
+
+        ITEMISZED_PREFIX_LEN = 12
+
+        changes = dry_run_output.strip().split("\n")
+        for line in changes:
+            if (
+                not line or len(line) < ITEMISZED_PREFIX_LEN
+            ):  # Need at least "<fcsT......" part
+                continue
+            if line.startswith("*deleting"):
+                deleting_files.append(line[ITEMISZED_PREFIX_LEN:])
+            elif line[2] == "c":  # Check the checksum position
+                modifying_files.append(line[ITEMISZED_PREFIX_LEN:])
+
+        return modifying_files, deleting_files
+
+    def _dry_run_rsync(self, rsync_command: List[str], delete: bool):
+        """Run rsync with --dry-run and warn if files are being deleted.
+        """
+
+        # --itemize-changes is needed to detect file changes
+        dry_run_options = ["--dry-run", "--itemize-changes"]
+        should_warn_delete = False
+
+        if not delete:
+            # --delete-excluded is needed to detect files that are being deleted in the destination
+            should_warn_delete = True
+            dry_run_options.append("--delete-excluded")
+
+        result = subprocess.run(
+            rsync_command + dry_run_options, capture_output=True, text=True, check=True
+        )
+        if result.returncode != 0:
+            raise RuntimeError(f"Rsync failed with return code {result.returncode}")
+
+        _, deleting_files = self._parse_rsync_dry_run_output(result.stdout)
+
+        if should_warn_delete and len(deleting_files):
+            click.echo(
+                "Detected files that exist in the destination but not in the source. The files will not be deleted by default. You can add '--delete' option to delete the files:"
+            )
+            click.echo(
+                "\n".join([click.style(file, fg="red") for file in deleting_files])
+            )
+
     def _run_rsync(
         self,
         *,
@@ -382,6 +449,7 @@ class PrivateWorkspaceSDK(WorkloadSDK):
         rsync_args: Optional[List[str]] = None,
         is_pull: bool = False,
         include_git_state: bool = False,
+        delete: bool = False,
     ):
         workspace_model = self._resolve_to_workspace_model(
             id=id, name=name, cloud=cloud, project=project
@@ -405,9 +473,6 @@ class PrivateWorkspaceSDK(WorkloadSDK):
 
             rsync_args = rsync_args or []
 
-            # delete files in destination that are not in source by default
-            rsync_args += ["--delete"]
-
             # exclude .git/objects/info/alternates since we will repack the git repo if needed
             # exclude .anyscale.yaml for legacy reasons
             rsync_args += [
@@ -426,18 +491,29 @@ class PrivateWorkspaceSDK(WorkloadSDK):
             elif not include_git_state:
                 rsync_args += ["--exclude", ".git"]
 
+            # Use -c (--checksum) to avoid retransmitting files that haven't changed
             args = [
                 "rsync",
-                "-rvzl",
+                "-rzlc",
                 "-e",
                 f"ssh -F {config_file} {subprocess.list2cmdline(ANYSCALE_WORKSPACES_SSH_OPTIONS)}",
                 source,
                 destination,
             ]
 
+            if delete:
+                # --delete-excluded is needed to delete files in the destination that are not in the source
+                # Note: We need --delete-excluded instead of --delete to delete files that are excluded from the sync, e.g. .git
+                args.append("--delete-excluded")
+
             if rsync_args:
                 args.extend(rsync_args)
 
+            self._dry_run_rsync(args, delete)
+
+            # Add -v / --verbose to the rsync command to be explicit about what is being transferred
+            args += ["-v"]
+
             subprocess.run(args, check=True)
 
     def pull(
@@ -450,6 +526,7 @@ class PrivateWorkspaceSDK(WorkloadSDK):
         local_dir: Optional[str] = None,
         pull_git_state: bool = False,
         rsync_args: Optional[List[str]] = None,
+        delete: bool = False,
     ):
         self._run_rsync(
             id=id,
@@ -460,6 +537,7 @@ class PrivateWorkspaceSDK(WorkloadSDK):
             rsync_args=rsync_args,
             is_pull=True,
             include_git_state=pull_git_state,
+            delete=delete,
         )
 
     def push(
@@ -472,6 +550,7 @@ class PrivateWorkspaceSDK(WorkloadSDK):
         local_dir: Optional[str] = None,
         push_git_state: bool = False,
         rsync_args: Optional[List[str]] = None,
+        delete: bool = False,
     ):
         self._run_rsync(
             id=id,
@@ -482,6 +561,7 @@ class PrivateWorkspaceSDK(WorkloadSDK):
             is_pull=False,
             include_git_state=push_git_state,
             rsync_args=rsync_args,
+            delete=delete,
         )
 
     def update(self, *, id: str, config: UpdateWorkspaceConfig) -> str:  # noqa: A002
