@@ -327,6 +327,7 @@ def pull(
     local_dir: Optional[str] = None,
     pull_git_state: bool = False,
     rsync_args: Optional[List[str]] = None,
+    delete: bool = False,
     _sdk: PrivateWorkspaceSDK,
 ) -> None:
     """Pull a workspace to a local directory.
@@ -341,6 +342,7 @@ def pull(
         local_dir=local_dir,
         pull_git_state=pull_git_state,
         rsync_args=rsync_args,
+        delete=delete,
     )
 
 
@@ -361,6 +363,7 @@ _PUSH_ARG_DOCSTRINGS = {
     "local_dir": "The local directory to push to the workspace. If not provided, the current working directory will be used.",
     "push_git_state": "Whether to push the git state of the workspace.",
     "rsync_args": "Additional arguments to pass to rsync.",
+    "delete": "Whether to delete files in the workspace that are not in the local directory.",
 }
 
 
@@ -379,6 +382,7 @@ def push(
     local_dir: Optional[str] = None,
     push_git_state: bool = False,
     rsync_args: Optional[List[str]] = None,
+    delete: bool = False,
     _sdk: PrivateWorkspaceSDK,
 ) -> None:
     """Push a local directory to a workspace.
@@ -393,6 +397,7 @@ def push(
         local_dir=local_dir,
         push_git_state=push_git_state,
         rsync_args=rsync_args,
+        delete=delete,
     )
 
 
