@@ -29,6 +29,7 @@ class WorkspaceState(ModelEnum):
 
 @dataclass(frozen=True)
 class UpdateWorkspaceConfig(ModelBase):
+    """Configuration options for updating a workspace."""
 
     __doc_py_example__ = """\
 from anyscale.workspace.models import UpdateWorkspaceConfig
@@ -190,6 +191,7 @@ requirements: /tmp/requirements.txt
 
 @dataclass(frozen=True)
 class WorkspaceConfig(UpdateWorkspaceConfig):
+    """Configuration options for a workspace."""
 
     __doc_py_example__ = """\
 from anyscale.workspace.models import WorkspaceConfig
